// gpio.h  

#if !defined( _GPIO_H_ )
#define _GPIO_H_

typedef struct
{ char *name;
  int  addr;
  int  def;
  int  value;
} VideoParam;

#define encoder_addr_reva  0x54
#define encoder_addr_revc  0x56
#define decoder_addr_reva  0x88
#define decoder_addr_revc  0x8a

#define GPIOADDR                  ((volatile unsigned long *)0xFFFFC000)

#define CROPPER_RESET_BIT         ((unsigned long)0x00800000)
#define FIRST_PIXEL_ACK_BIT       ((unsigned long)0x02000000)
#define FRAME_GRAB_TRIGGER_BIT    ((unsigned long)0x01000000)
#define FIRST_PIXEL_READY_BIT     ((unsigned long)0x80000000)

// definde for 32 bit gpio
//#define I2C_ENABLE_BIT            ((unsigned long)0x08000000)
//#define I2C_CLOCK_BIT             ((unsigned long)0x10000000)
//#define I2C_DATA_BIT              ((unsigned long)0x20000000)

// definded for 16 bit gpio
#define I2C_ENABLE_BIT            ((unsigned long)0x0800)
#define I2C_CLOCK_BIT             ((unsigned long)0x1000)
#define I2C_DATA_BIT              ((unsigned long)0x2000)
 
/* data in
31  1st pix ready
30  frame ready
29  i2c data
28  i2c clock
27  enable i2c
26  unused

data out
29  i2c data   (1= force low)
28  i2c clock  (1= force low)
27  enable i2c
26  unused
25  1st pix ack
24  trigger frame grab
23  reset cropper
*/

extern unsigned long gpio_shadow_register;


#define ping_gpio_bits( GPIO_MASK ) \
{ gpio_shadow_register |=  (GPIO_MASK); *GPIOADDR = gpio_shadow_register; \
  gpio_shadow_register &= ~(GPIO_MASK); *GPIOADDR = gpio_shadow_register; \
}

#define reset_cropper()             ping_gpio_bits( CROPPER_RESET_BIT )
#define acknowledge_first_pixel()   ping_gpio_bits( FIRST_PIXEL_ACK_BIT )
#define trigger_frame_grab()        ping_gpio_bits( FRAME_GRAB_TRIGGER_BIT )

#define test_first_pixel_ready()  (((*GPIOADDR) & FIRST_PIXEL_READY_BIT) != 0)

void enable_i2c( void );
void disable_i2c( void );
void set_i2c_clock( void );
void clear_i2c_clock( void );
void set_i2c_data( void );
void clear_i2c_data( void );
int test_i2c_clock( void );
int test_i2c_data( void );
int write_i2c_reg( int decoder, int addr, int val );

int program_video( void );

#endif // _GPIO_H_
