-------------------------------------------------------------------------------
-- jtag_inst_wrapper.vhd
-------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

library common_v1_00_a;
use common_v1_00_a.all;

library opb_jtag_uart_v1_00_b;
use opb_jtag_uart_v1_00_b.all;

entity jtag_inst_wrapper is
  port (
    OPB_Clk : in std_logic;
    OPB_Rst : in std_logic;
    Interrupt : out std_logic;
    Debug_SYS_Rst : out std_logic;
    Debug_Rst : out std_logic;
    Ext_BRK : out std_logic;
    Ext_NM_BRK : out std_logic;
    OPB_ABus : in std_logic_vector(0 to 31);
    OPB_BE : in std_logic_vector(0 to 3);
    OPB_RNW : in std_logic;
    OPB_select : in std_logic;
    OPB_seqAddr : in std_logic;
    OPB_DBus : in std_logic_vector(0 to 31);
    JTAG_UART_DBus : out std_logic_vector(0 to 31);
    JTAG_UART_errAck : out std_logic;
    JTAG_UART_retry : out std_logic;
    JTAG_UART_toutSup : out std_logic;
    JTAG_UART_xferAck : out std_logic
  );
end jtag_inst_wrapper;

architecture STRUCTURE of jtag_inst_wrapper is

  component opb_jtag_uart is
    generic (
      C_BASEADDR : std_logic_vector;
      C_HIGHADDR : std_logic_vector;
      C_OPB_DWIDTH : integer;
      C_OPB_AWIDTH : integer;
      C_FAMILY : string
    );
    port (
      OPB_Clk : in std_logic;
      OPB_Rst : in std_logic;
      Interrupt : out std_logic;
      Debug_SYS_Rst : out std_logic;
      Debug_Rst : out std_logic;
      Ext_BRK : out std_logic;
      Ext_NM_BRK : out std_logic;
      OPB_ABus : in std_logic_vector(0 to C_OPB_AWIDTH-1);
      OPB_BE : in std_logic_vector(0 to C_OPB_DWIDTH/8-1);
      OPB_RNW : in std_logic;
      OPB_select : in std_logic;
      OPB_seqAddr : in std_logic;
      OPB_DBus : in std_logic_vector(0 to C_OPB_DWIDTH-1);
      JTAG_UART_DBus : out std_logic_vector(0 to C_OPB_DWIDTH-1);
      JTAG_UART_errAck : out std_logic;
      JTAG_UART_retry : out std_logic;
      JTAG_UART_toutSup : out std_logic;
      JTAG_UART_xferAck : out std_logic
    );
  end component;

begin

  jtag_inst : opb_jtag_uart
    generic map (
      C_BASEADDR => X"FFFF8000",
      C_HIGHADDR => X"FFFF80FF",
      C_OPB_DWIDTH => 32,
      C_OPB_AWIDTH => 32,
      C_FAMILY => "virtex2"
    )
    port map (
      OPB_Clk => OPB_Clk,
      OPB_Rst => OPB_Rst,
      Interrupt => Interrupt,
      Debug_SYS_Rst => Debug_SYS_Rst,
      Debug_Rst => Debug_Rst,
      Ext_BRK => Ext_BRK,
      Ext_NM_BRK => Ext_NM_BRK,
      OPB_ABus => OPB_ABus,
      OPB_BE => OPB_BE,
      OPB_RNW => OPB_RNW,
      OPB_select => OPB_select,
      OPB_seqAddr => OPB_seqAddr,
      OPB_DBus => OPB_DBus,
      JTAG_UART_DBus => JTAG_UART_DBus,
      JTAG_UART_errAck => JTAG_UART_errAck,
      JTAG_UART_retry => JTAG_UART_retry,
      JTAG_UART_toutSup => JTAG_UART_toutSup,
      JTAG_UART_xferAck => JTAG_UART_xferAck
    );

end architecture STRUCTURE;
