-------------------------------------------------------------------------------
-- system.vhd
-------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

entity system is
  port (
    MEMORY_BANK2_DATA : inout std_logic_vector(0 to 31);
    MEMORY_BANK2_CLKEN_N : out std_logic;
    MEMORY_BANK2_CEN_N : out std_logic;
    MEMORY_BANK2_OEN_N : out std_logic;
    MEMORY_BANK2_WEN : out std_logic_vector(1 to 4);
    MEMORY_BANK2_WEN_N : out std_logic;
    MEMORY_BANK2_ADV_LD_N : out std_logic;
    MEMORY_BANK2_ADDR_P : out std_logic_vector(0 to 18);
    MDC_P : out std_logic;
    MDIO_P : out std_logic;
    MASTER_CLOCK_P : in std_logic;
    STARTUP_P : out std_logic;
    MEMORY_BANK2_CLK_P : out std_logic;
    PAUSE_P : out std_logic;
    ENET_SLEW_P : out std_logic_vector(1 downto 0);
    EXTEND_DCM_RESET_P : in std_logic;
    LINE_LOCKED_CLOCK1 : in std_logic;
    PAL_NTSC_N : in std_logic;
    S_VIDEO_N : in std_logic;
    USER_INPUT1_P : in std_logic;
    I2C_CLOCK_P : out std_logic;
    I2C_DATA_P : out std_logic;
    VIDEO_ENCODER_DATA_P : out std_logic;
    VIDEO_ENCODER_SCLK_P : out std_logic;
    YCRCB : in std_logic_vector(9 downto 0);
    YCRCB_P : out std_logic_vector(9 downto 0);
    PB_DATA_P : in std_logic;
    PB_CLOCK_P : in std_logic;
    RS232_TX_DATA_P : out std_logic;
    RS232_RX_DATA_P : in std_logic;
    MEM_CLK_FBOUT_P : out std_logic;
    TV_OUT_BLANK_N : out std_logic;
    TV_OUT_PAL_NTSC_N : out std_logic
  );
end system;

architecture STRUCTURE of system is

  attribute box_type : string;

  component microblaze_inst_wrapper is
    port (
      CLK : in std_logic;
      RESET : in std_logic;
      INTERRUPT : in std_logic;
      DEBUG_RST : in std_logic;
      EXT_BRK : in std_logic;
      EXT_NM_BRK : in std_logic;
      DBG_STOP : in std_logic;
      INSTR : in std_logic_vector(0 to 31);
      IREADY : in std_logic;
      INSTR_ADDR : out std_logic_vector(0 to 31);
      IFETCH : out std_logic;
      I_AS : out std_logic;
      DATA_READ : in std_logic_vector(0 to 31);
      DREADY : in std_logic;
      DATA_WRITE : out std_logic_vector(0 to 31);
      DATA_ADDR : out std_logic_vector(0 to 31);
      D_AS : out std_logic;
      READ_STROBE : out std_logic;
      WRITE_STROBE : out std_logic;
      BYTE_ENABLE : out std_logic_vector(0 to 3);
      DM_ABUS : out std_logic_vector(0 to 31);
      DM_BE : out std_logic_vector(0 to 3);
      DM_BUSLOCK : out std_logic;
      DM_DBUS : out std_logic_vector(0 to 31);
      DM_REQUEST : out std_logic;
      DM_RNW : out std_logic;
      DM_SELECT : out std_logic;
      DM_SEQADDR : out std_logic;
      DOPB_DBUS : in std_logic_vector(0 to 31);
      DOPB_ERRACK : in std_logic;
      DOPB_MGRANT : in std_logic;
      DOPB_RETRY : in std_logic;
      DOPB_TIMEOUT : in std_logic;
      DOPB_XFERACK : in std_logic;
      IM_ABUS : out std_logic_vector(0 to 31);
      IM_BE : out std_logic_vector(0 to 3);
      IM_BUSLOCK : out std_logic;
      IM_DBUS : out std_logic_vector(0 to 31);
      IM_REQUEST : out std_logic;
      IM_RNW : out std_logic;
      IM_SELECT : out std_logic;
      IM_SEQADDR : out std_logic;
      IOPB_DBUS : in std_logic_vector(0 to 31);
      IOPB_ERRACK : in std_logic;
      IOPB_MGRANT : in std_logic;
      IOPB_RETRY : in std_logic;
      IOPB_TIMEOUT : in std_logic;
      IOPB_XFERACK : in std_logic;
      DBG_CLK : in std_logic;
      DBG_TDI : in std_logic;
      DBG_TDO : out std_logic;
      DBG_REG_EN : in std_logic_vector(0 to 4);
      DBG_CAPTURE : in std_logic;
      DBG_UPDATE : in std_logic;
      VALID_INSTR : out std_logic;
      PC_EX : out std_logic_vector(0 to 31);
      REG_WRITE : out std_logic;
      REG_ADDR : out std_logic_vector(0 to 4);
      MSR_REG : out std_logic_vector(0 to 7);
      NEW_REG_VALUE : out std_logic_vector(0 to 31);
      PIPE_RUNNING : out std_logic;
      INTERRUPT_TAKEN : out std_logic;
      JUMP_TAKEN : out std_logic;
      PREFETCH_ADDR : out std_logic_vector(0 to 3);
      MB_Halted : out std_logic;
      FSL0_S_CLK : out std_logic;
      FSL0_S_READ : out std_logic;
      FSL0_S_DATA : in std_logic_vector(0 to 31);
      FSL0_S_CONTROL : in std_logic;
      FSL0_S_EXISTS : in std_logic;
      FSL0_M_CLK : out std_logic;
      FSL0_M_WRITE : out std_logic;
      FSL0_M_DATA : out std_logic_vector(0 to 31);
      FSL0_M_CONTROL : out std_logic;
      FSL0_M_FULL : in std_logic;
      FSL1_S_CLK : out std_logic;
      FSL1_S_READ : out std_logic;
      FSL1_S_DATA : in std_logic_vector(0 to 31);
      FSL1_S_CONTROL : in std_logic;
      FSL1_S_EXISTS : in std_logic;
      FSL1_M_CLK : out std_logic;
      FSL1_M_WRITE : out std_logic;
      FSL1_M_DATA : out std_logic_vector(0 to 31);
      FSL1_M_CONTROL : out std_logic;
      FSL1_M_FULL : in std_logic;
      FSL2_S_CLK : out std_logic;
      FSL2_S_READ : out std_logic;
      FSL2_S_DATA : in std_logic_vector(0 to 31);
      FSL2_S_CONTROL : in std_logic;
      FSL2_S_EXISTS : in std_logic;
      FSL2_M_CLK : out std_logic;
      FSL2_M_WRITE : out std_logic;
      FSL2_M_DATA : out std_logic_vector(0 to 31);
      FSL2_M_CONTROL : out std_logic;
      FSL2_M_FULL : in std_logic;
      FSL3_S_CLK : out std_logic;
      FSL3_S_READ : out std_logic;
      FSL3_S_DATA : in std_logic_vector(0 to 31);
      FSL3_S_CONTROL : in std_logic;
      FSL3_S_EXISTS : in std_logic;
      FSL3_M_CLK : out std_logic;
      FSL3_M_WRITE : out std_logic;
      FSL3_M_DATA : out std_logic_vector(0 to 31);
      FSL3_M_CONTROL : out std_logic;
      FSL3_M_FULL : in std_logic;
      FSL4_S_CLK : out std_logic;
      FSL4_S_READ : out std_logic;
      FSL4_S_DATA : in std_logic_vector(0 to 31);
      FSL4_S_CONTROL : in std_logic;
      FSL4_S_EXISTS : in std_logic;
      FSL4_M_CLK : out std_logic;
      FSL4_M_WRITE : out std_logic;
      FSL4_M_DATA : out std_logic_vector(0 to 31);
      FSL4_M_CONTROL : out std_logic;
      FSL4_M_FULL : in std_logic;
      FSL5_S_CLK : out std_logic;
      FSL5_S_READ : out std_logic;
      FSL5_S_DATA : in std_logic_vector(0 to 31);
      FSL5_S_CONTROL : in std_logic;
      FSL5_S_EXISTS : in std_logic;
      FSL5_M_CLK : out std_logic;
      FSL5_M_WRITE : out std_logic;
      FSL5_M_DATA : out std_logic_vector(0 to 31);
      FSL5_M_CONTROL : out std_logic;
      FSL5_M_FULL : in std_logic;
      FSL6_S_CLK : out std_logic;
      FSL6_S_READ : out std_logic;
      FSL6_S_DATA : in std_logic_vector(0 to 31);
      FSL6_S_CONTROL : in std_logic;
      FSL6_S_EXISTS : in std_logic;
      FSL6_M_CLK : out std_logic;
      FSL6_M_WRITE : out std_logic;
      FSL6_M_DATA : out std_logic_vector(0 to 31);
      FSL6_M_CONTROL : out std_logic;
      FSL6_M_FULL : in std_logic;
      FSL7_S_CLK : out std_logic;
      FSL7_S_READ : out std_logic;
      FSL7_S_DATA : in std_logic_vector(0 to 31);
      FSL7_S_CONTROL : in std_logic;
      FSL7_S_EXISTS : in std_logic;
      FSL7_M_CLK : out std_logic;
      FSL7_M_WRITE : out std_logic;
      FSL7_M_DATA : out std_logic_vector(0 to 31);
      FSL7_M_CONTROL : out std_logic;
      FSL7_M_FULL : in std_logic
    );
  end component;

  attribute box_type of microblaze_inst_wrapper: component is "black_box";

  component d_lmb_wrapper is
    port (
      LMB_Clk : in std_logic;
      SYS_Rst : in std_logic;
      LMB_Rst : out std_logic;
      M_ABus : in std_logic_vector(0 to 31);
      M_ReadStrobe : in std_logic;
      M_WriteStrobe : in std_logic;
      M_AddrStrobe : in std_logic;
      M_DBus : in std_logic_vector(0 to 31);
      M_BE : in std_logic_vector(0 to 3);
      Sl_DBus : in std_logic_vector(0 to 31);
      Sl_Ready : in std_logic_vector(0 to 0);
      LMB_ABus : out std_logic_vector(0 to 31);
      LMB_ReadStrobe : out std_logic;
      LMB_WriteStrobe : out std_logic;
      LMB_AddrStrobe : out std_logic;
      LMB_ReadDBus : out std_logic_vector(0 to 31);
      LMB_WriteDBus : out std_logic_vector(0 to 31);
      LMB_Ready : out std_logic;
      LMB_BE : out std_logic_vector(0 to 3)
    );
  end component;

  attribute box_type of d_lmb_wrapper: component is "black_box";

  component i_lmb_wrapper is
    port (
      LMB_Clk : in std_logic;
      SYS_Rst : in std_logic;
      LMB_Rst : out std_logic;
      M_ABus : in std_logic_vector(0 to 31);
      M_ReadStrobe : in std_logic;
      M_WriteStrobe : in std_logic;
      M_AddrStrobe : in std_logic;
      M_DBus : in std_logic_vector(0 to 31);
      M_BE : in std_logic_vector(0 to 3);
      Sl_DBus : in std_logic_vector(0 to 31);
      Sl_Ready : in std_logic_vector(0 to 0);
      LMB_ABus : out std_logic_vector(0 to 31);
      LMB_ReadStrobe : out std_logic;
      LMB_WriteStrobe : out std_logic;
      LMB_AddrStrobe : out std_logic;
      LMB_ReadDBus : out std_logic_vector(0 to 31);
      LMB_WriteDBus : out std_logic_vector(0 to 31);
      LMB_Ready : out std_logic;
      LMB_BE : out std_logic_vector(0 to 3)
    );
  end component;

  attribute box_type of i_lmb_wrapper: component is "black_box";

  component myopb_bus_wrapper is
    port (
      OPB_Clk : in std_logic;
      OPB_Rst : out std_logic;
      SYS_Rst : in std_logic;
      Debug_SYS_Rst : in std_logic;
      WDT_Rst : in std_logic;
      M_ABus : in std_logic_vector(0 to 63);
      M_BE : in std_logic_vector(0 to 7);
      M_beXfer : in std_logic_vector(0 to 1);
      M_busLock : in std_logic_vector(0 to 1);
      M_DBus : in std_logic_vector(0 to 63);
      M_DBusEn : in std_logic_vector(0 to 1);
      M_DBusEn32_63 : in std_logic_vector(0 to 1);
      M_dwXfer : in std_logic_vector(0 to 1);
      M_fwXfer : in std_logic_vector(0 to 1);
      M_hwXfer : in std_logic_vector(0 to 1);
      M_request : in std_logic_vector(0 to 1);
      M_RNW : in std_logic_vector(0 to 1);
      M_select : in std_logic_vector(0 to 1);
      M_seqAddr : in std_logic_vector(0 to 1);
      Sl_beAck : in std_logic_vector(0 to 7);
      Sl_DBus : in std_logic_vector(0 to 255);
      Sl_DBusEn : in std_logic_vector(0 to 7);
      Sl_DBusEn32_63 : in std_logic_vector(0 to 7);
      Sl_errAck : in std_logic_vector(0 to 7);
      Sl_dwAck : in std_logic_vector(0 to 7);
      Sl_fwAck : in std_logic_vector(0 to 7);
      Sl_hwAck : in std_logic_vector(0 to 7);
      Sl_retry : in std_logic_vector(0 to 7);
      Sl_toutSup : in std_logic_vector(0 to 7);
      Sl_xferAck : in std_logic_vector(0 to 7);
      OPB_MRequest : out std_logic_vector(0 to 1);
      OPB_ABus : out std_logic_vector(0 to 31);
      OPB_BE : out std_logic_vector(0 to 3);
      OPB_beXfer : out std_logic;
      OPB_beAck : out std_logic;
      OPB_busLock : out std_logic;
      OPB_rdDBus : out std_logic_vector(0 to 31);
      OPB_wrDBus : out std_logic_vector(0 to 31);
      OPB_DBus : out std_logic_vector(0 to 31);
      OPB_errAck : out std_logic;
      OPB_dwAck : out std_logic;
      OPB_dwXfer : out std_logic;
      OPB_fwAck : out std_logic;
      OPB_fwXfer : out std_logic;
      OPB_hwAck : out std_logic;
      OPB_hwXfer : out std_logic;
      OPB_MGrant : out std_logic_vector(0 to 1);
      OPB_pendReq : out std_logic_vector(0 to 1);
      OPB_retry : out std_logic;
      OPB_RNW : out std_logic;
      OPB_select : out std_logic;
      OPB_seqAddr : out std_logic;
      OPB_timeout : out std_logic;
      OPB_toutSup : out std_logic;
      OPB_xferAck : out std_logic
    );
  end component;

  attribute box_type of myopb_bus_wrapper: component is "black_box";

  component dlmb_cntlr_wrapper is
    port (
      LMB_Clk : in std_logic;
      LMB_Rst : in std_logic;
      LMB_ABus : in std_logic_vector(0 to 31);
      LMB_WriteDBus : in std_logic_vector(0 to 31);
      LMB_AddrStrobe : in std_logic;
      LMB_ReadStrobe : in std_logic;
      LMB_WriteStrobe : in std_logic;
      LMB_BE : in std_logic_vector(0 to 3);
      Sl_DBus : out std_logic_vector(0 to 31);
      Sl_Ready : out std_logic;
      BRAM_Rst_A : out std_logic;
      BRAM_Clk_A : out std_logic;
      BRAM_EN_A : out std_logic;
      BRAM_WEN_A : out std_logic_vector(0 to 3);
      BRAM_Addr_A : out std_logic_vector(0 to 31);
      BRAM_Din_A : in std_logic_vector(0 to 31);
      BRAM_Dout_A : out std_logic_vector(0 to 31)
    );
  end component;

  attribute box_type of dlmb_cntlr_wrapper: component is "black_box";

  component ilmb_cntlr_wrapper is
    port (
      LMB_Clk : in std_logic;
      LMB_Rst : in std_logic;
      LMB_ABus : in std_logic_vector(0 to 31);
      LMB_WriteDBus : in std_logic_vector(0 to 31);
      LMB_AddrStrobe : in std_logic;
      LMB_ReadStrobe : in std_logic;
      LMB_WriteStrobe : in std_logic;
      LMB_BE : in std_logic_vector(0 to 3);
      Sl_DBus : out std_logic_vector(0 to 31);
      Sl_Ready : out std_logic;
      BRAM_Rst_A : out std_logic;
      BRAM_Clk_A : out std_logic;
      BRAM_EN_A : out std_logic;
      BRAM_WEN_A : out std_logic_vector(0 to 3);
      BRAM_Addr_A : out std_logic_vector(0 to 31);
      BRAM_Din_A : in std_logic_vector(0 to 31);
      BRAM_Dout_A : out std_logic_vector(0 to 31)
    );
  end component;

  attribute box_type of ilmb_cntlr_wrapper: component is "black_box";

  component bram_inst_wrapper is
    port (
      BRAM_Rst_A : in std_logic;
      BRAM_Clk_A : in std_logic;
      BRAM_EN_A : in std_logic;
      BRAM_WEN_A : in std_logic_vector(0 to 3);
      BRAM_Addr_A : in std_logic_vector(0 to 31);
      BRAM_Din_A : out std_logic_vector(0 to 31);
      BRAM_Dout_A : in std_logic_vector(0 to 31);
      BRAM_Rst_B : in std_logic;
      BRAM_Clk_B : in std_logic;
      BRAM_EN_B : in std_logic;
      BRAM_WEN_B : in std_logic_vector(0 to 3);
      BRAM_Addr_B : in std_logic_vector(0 to 31);
      BRAM_Din_B : out std_logic_vector(0 to 31);
      BRAM_Dout_B : in std_logic_vector(0 to 31)
    );
  end component;

  attribute box_type of bram_inst_wrapper: component is "black_box";

  component zbt_cntlr_wrapper is
    port (
      OPB_Clk : in std_logic;
      OPB_Rst : in std_logic;
      OPB_ABus : in std_logic_vector(0 to 31);
      OPB_BE : in std_logic_vector(0 to 3);
      OPB_RNW : in std_logic;
      OPB_select : in std_logic;
      OPB_seqAddr : in std_logic;
      OPB_DBus : in std_logic_vector(0 to 31);
      ZBT_DBus : out std_logic_vector(0 to 31);
      ZBT_errAck : out std_logic;
      ZBT_retry : out std_logic;
      ZBT_toutSup : out std_logic;
      ZBT_xferAck : out std_logic;
      ZBT_Clk_FB : in std_logic;
      ZBT_Clk_FBOut : out std_logic;
      ZBT_Clk : out std_logic;
      ZBT_OE_N : out std_logic;
      ZBT_ADV_LD_N : out std_logic;
      ZBT_LBO_N : out std_logic;
      ZBT_CE1_N : out std_logic;
      ZBT_CE2_N : out std_logic;
      ZBT_CE2 : out std_logic;
      ZBT_RW_N : out std_logic;
      ZBT_CKE_N : out std_logic;
      ZBT_A : out std_logic_vector(0 to 18);
      ZBT_BW_N : out std_logic_vector(1 to 4);
      ZBT_IO_I : in std_logic_vector(0 to 31);
      ZBT_IO_O : out std_logic_vector(0 to 31);
      ZBT_IO_T : out std_logic;
      ZBT_IOP_I : in std_logic_vector(1 to 4);
      ZBT_IOP_O : out std_logic_vector(1 to 4);
      ZBT_IOP_T : out std_logic
    );
  end component;

  attribute box_type of zbt_cntlr_wrapper: component is "black_box";

  component jtag_inst_wrapper is
    port (
      OPB_Clk : in std_logic;
      OPB_Rst : in std_logic;
      Interrupt : out std_logic;
      Debug_SYS_Rst : out std_logic;
      Debug_Rst : out std_logic;
      Ext_BRK : out std_logic;
      Ext_NM_BRK : out std_logic;
      OPB_ABus : in std_logic_vector(0 to 31);
      OPB_BE : in std_logic_vector(0 to 3);
      OPB_RNW : in std_logic;
      OPB_select : in std_logic;
      OPB_seqAddr : in std_logic;
      OPB_DBus : in std_logic_vector(0 to 31);
      JTAG_UART_DBus : out std_logic_vector(0 to 31);
      JTAG_UART_errAck : out std_logic;
      JTAG_UART_retry : out std_logic;
      JTAG_UART_toutSup : out std_logic;
      JTAG_UART_xferAck : out std_logic
    );
  end component;

  attribute box_type of jtag_inst_wrapper: component is "black_box";

  component uart_inst_wrapper is
    port (
      OPB_Clk : in std_logic;
      OPB_Rst : in std_logic;
      Interrupt : out std_logic;
      OPB_ABus : in std_logic_vector(0 to 31);
      OPB_BE : in std_logic_vector(0 to 3);
      OPB_RNW : in std_logic;
      OPB_select : in std_logic;
      OPB_seqAddr : in std_logic;
      OPB_DBus : in std_logic_vector(0 to 31);
      UART_DBus : out std_logic_vector(0 to 31);
      UART_errAck : out std_logic;
      UART_retry : out std_logic;
      UART_toutSup : out std_logic;
      UART_xferAck : out std_logic;
      RX : in std_logic;
      TX : out std_logic
    );
  end component;

  attribute box_type of uart_inst_wrapper: component is "black_box";

  component gpio_button_in_wrapper is
    port (
      OPB_ABus : in std_logic_vector(0 to 31);
      OPB_BE : in std_logic_vector(0 to 3);
      OPB_Clk : in std_logic;
      OPB_DBus : in std_logic_vector(0 to 31);
      OPB_RNW : in std_logic;
      OPB_Rst : in std_logic;
      OPB_select : in std_logic;
      OPB_seqAddr : in std_logic;
      Sln_DBus : out std_logic_vector(0 to 31);
      Sln_errAck : out std_logic;
      Sln_retry : out std_logic;
      Sln_toutSup : out std_logic;
      Sln_xferAck : out std_logic;
      Device_Intr : out std_logic;
      GPIO_in : in std_logic_vector(0 to 7);
      GPIO_d_out : out std_logic_vector(0 to 7);
      GPIO_t_out : out std_logic_vector(0 to 7);
      GPIO2_in : in std_logic_vector(0 to 7);
      GPIO2_d_out : out std_logic_vector(0 to 7);
      GPIO2_t_out : out std_logic_vector(0 to 7);
      GPIO_IO_I : in std_logic_vector(0 to 7);
      GPIO_IO_O : out std_logic_vector(0 to 7);
      GPIO_IO_T : out std_logic_vector(0 to 7);
      GPIO2_IO_I : in std_logic_vector(0 to 7);
      GPIO2_IO_O : out std_logic_vector(0 to 7);
      GPIO2_IO_T : out std_logic_vector(0 to 7)
    );
  end component;

  attribute box_type of gpio_button_in_wrapper: component is "black_box";

  component gpio_y_wrapper is
    port (
      OPB_ABus : in std_logic_vector(0 to 31);
      OPB_BE : in std_logic_vector(0 to 3);
      OPB_Clk : in std_logic;
      OPB_DBus : in std_logic_vector(0 to 31);
      OPB_RNW : in std_logic;
      OPB_Rst : in std_logic;
      OPB_select : in std_logic;
      OPB_seqAddr : in std_logic;
      Sln_DBus : out std_logic_vector(0 to 31);
      Sln_errAck : out std_logic;
      Sln_retry : out std_logic;
      Sln_toutSup : out std_logic;
      Sln_xferAck : out std_logic;
      Device_Intr : out std_logic;
      GPIO_in : in std_logic_vector(0 to 9);
      GPIO_d_out : out std_logic_vector(0 to 9);
      GPIO_t_out : out std_logic_vector(0 to 9);
      GPIO2_in : in std_logic_vector(0 to 9);
      GPIO2_d_out : out std_logic_vector(0 to 9);
      GPIO2_t_out : out std_logic_vector(0 to 9);
      GPIO_IO_I : in std_logic_vector(0 to 9);
      GPIO_IO_O : out std_logic_vector(0 to 9);
      GPIO_IO_T : out std_logic_vector(0 to 9);
      GPIO2_IO_I : in std_logic_vector(0 to 9);
      GPIO2_IO_O : out std_logic_vector(0 to 9);
      GPIO2_IO_T : out std_logic_vector(0 to 9)
    );
  end component;

  attribute box_type of gpio_y_wrapper: component is "black_box";

  component gpio_cr_wrapper is
    port (
      OPB_ABus : in std_logic_vector(0 to 31);
      OPB_BE : in std_logic_vector(0 to 3);
      OPB_Clk : in std_logic;
      OPB_DBus : in std_logic_vector(0 to 31);
      OPB_RNW : in std_logic;
      OPB_Rst : in std_logic;
      OPB_select : in std_logic;
      OPB_seqAddr : in std_logic;
      Sln_DBus : out std_logic_vector(0 to 31);
      Sln_errAck : out std_logic;
      Sln_retry : out std_logic;
      Sln_toutSup : out std_logic;
      Sln_xferAck : out std_logic;
      Device_Intr : out std_logic;
      GPIO_in : in std_logic_vector(0 to 9);
      GPIO_d_out : out std_logic_vector(0 to 9);
      GPIO_t_out : out std_logic_vector(0 to 9);
      GPIO2_in : in std_logic_vector(0 to 9);
      GPIO2_d_out : out std_logic_vector(0 to 9);
      GPIO2_t_out : out std_logic_vector(0 to 9);
      GPIO_IO_I : in std_logic_vector(0 to 9);
      GPIO_IO_O : out std_logic_vector(0 to 9);
      GPIO_IO_T : out std_logic_vector(0 to 9);
      GPIO2_IO_I : in std_logic_vector(0 to 9);
      GPIO2_IO_O : out std_logic_vector(0 to 9);
      GPIO2_IO_T : out std_logic_vector(0 to 9)
    );
  end component;

  attribute box_type of gpio_cr_wrapper: component is "black_box";

  component gpio_cb_wrapper is
    port (
      OPB_ABus : in std_logic_vector(0 to 31);
      OPB_BE : in std_logic_vector(0 to 3);
      OPB_Clk : in std_logic;
      OPB_DBus : in std_logic_vector(0 to 31);
      OPB_RNW : in std_logic;
      OPB_Rst : in std_logic;
      OPB_select : in std_logic;
      OPB_seqAddr : in std_logic;
      Sln_DBus : out std_logic_vector(0 to 31);
      Sln_errAck : out std_logic;
      Sln_retry : out std_logic;
      Sln_toutSup : out std_logic;
      Sln_xferAck : out std_logic;
      Device_Intr : out std_logic;
      GPIO_in : in std_logic_vector(0 to 9);
      GPIO_d_out : out std_logic_vector(0 to 9);
      GPIO_t_out : out std_logic_vector(0 to 9);
      GPIO2_in : in std_logic_vector(0 to 9);
      GPIO2_d_out : out std_logic_vector(0 to 9);
      GPIO2_t_out : out std_logic_vector(0 to 9);
      GPIO_IO_I : in std_logic_vector(0 to 9);
      GPIO_IO_O : out std_logic_vector(0 to 9);
      GPIO_IO_T : out std_logic_vector(0 to 9);
      GPIO2_IO_I : in std_logic_vector(0 to 9);
      GPIO2_IO_O : out std_logic_vector(0 to 9);
      GPIO2_IO_T : out std_logic_vector(0 to 9)
    );
  end component;

  attribute box_type of gpio_cb_wrapper: component is "black_box";

  component clock_gen_inst_wrapper is
    port (
      master_clock_p : in std_logic;
      line_locked_clock1 : in std_logic;
      extend_dcm_reset_p : in std_logic;
      memory_bank2_clk_p : out std_logic;
      clk_27mhz : out std_logic;
      line_locked_clock : out std_logic;
      clk_81mhz : out std_logic;
      fpga_reset : out std_logic;
      enet_slew_p : out std_logic_vector(1 downto 0);
      pause_p : out std_logic;
      mdio_p : out std_logic;
      mdc_p : out std_logic;
      startup_p : out std_logic
    );
  end component;

  attribute box_type of clock_gen_inst_wrapper: component is "black_box";

  component gpio_mod_inst_wrapper is
    port (
      OPB_Clk : in std_logic;
      OPB_Rst : in std_logic;
      OPB_ABus : in std_logic_vector(0 to 31);
      OPB_BE : in std_logic_vector(0 to 3);
      OPB_DBus : in std_logic_vector(0 to 31);
      OPB_RNW : in std_logic;
      OPB_select : in std_logic;
      OPB_seqAddr : in std_logic;
      GPIO_DBus : out std_logic_vector(0 to 31);
      GPIO_errAck : out std_logic;
      GPIO_retry : out std_logic;
      GPIO_toutSup : out std_logic;
      GPIO_xferAck : out std_logic;
      GPIO_IO_I0 : in std_logic;
      GPIO_IO_I1 : in std_logic;
      GPIO_IO_I2 : in std_logic;
      GPIO_IO_I3 : in std_logic;
      GPIO_IO_I4 : in std_logic;
      GPIO_IO_I5 : in std_logic;
      GPIO_IO_I6 : in std_logic;
      GPIO_IO_I7 : in std_logic;
      GPIO_IO_I8 : in std_logic;
      GPIO_IO_I9 : in std_logic;
      GPIO_IO_I10 : in std_logic;
      GPIO_IO_I11 : in std_logic;
      GPIO_IO_I12 : in std_logic;
      GPIO_IO_I13 : in std_logic;
      GPIO_IO_I14 : in std_logic;
      GPIO_IO_I15 : in std_logic;
      GPIO_IO_O0 : out std_logic;
      GPIO_IO_O1 : out std_logic;
      GPIO_IO_O2 : out std_logic;
      GPIO_IO_O3 : out std_logic;
      GPIO_IO_O4 : out std_logic;
      GPIO_IO_O5 : out std_logic;
      GPIO_IO_O6 : out std_logic;
      GPIO_IO_O7 : out std_logic;
      GPIO_IO_O8 : out std_logic;
      GPIO_IO_O9 : out std_logic;
      GPIO_IO_O10 : out std_logic;
      GPIO_IO_O11 : out std_logic;
      GPIO_IO_O12 : out std_logic;
      GPIO_IO_O13 : out std_logic;
      GPIO_IO_O14 : out std_logic;
      GPIO_IO_O15 : out std_logic
    );
  end component;

  attribute box_type of gpio_mod_inst_wrapper: component is "black_box";

  component gpio2iic_inst_wrapper is
    port (
      gpio_data_i2 : out std_logic;
      gpio_data_i3 : out std_logic;
      gpio_data_o2 : in std_logic;
      gpio_data_o3 : in std_logic;
      gpio_data_o4 : in std_logic;
      video_encoder_sclk_p : out std_logic;
      video_encoder_data_p : out std_logic;
      i2c_clock_p : out std_logic;
      i2c_data_p : out std_logic
    );
  end component;

  attribute box_type of gpio2iic_inst_wrapper: component is "black_box";

  component vid_resync_buf_inst_wrapper is
    port (
      vid_27mhz_input_clock : in std_logic;
      vid_27mhz_output_clock : in std_logic;
      reset : in std_logic;
      YCrCb_input : in std_logic_vector(9 downto 0);
      YCrCb_reg_out : out std_logic_vector(9 downto 0)
    );
  end component;

  attribute box_type of vid_resync_buf_inst_wrapper: component is "black_box";

  component video_block_inst_wrapper is
    port (
      reset : in std_logic;
      clock : in std_logic;
      YCrCb_in : in std_logic_vector(9 downto 0);
      pixel_data_in : in std_logic_vector(9 downto 0);
      synch_data_in : in std_logic_vector(9 downto 0);
      YCrCb_out : out std_logic_vector(9 downto 0);
      pixel_data_out : out std_logic_vector(9 downto 0);
      synch_data_out : out std_logic_vector(9 downto 0);
      reset_out : out std_logic
    );
  end component;

  attribute box_type of video_block_inst_wrapper: component is "black_box";

  component demultiplexer_inst_wrapper is
    port (
      reset : in std_logic;
      clock : in std_logic;
      YCrCb_in : in std_logic_vector(9 downto 0);
      Y_out : out std_logic_vector(9 downto 0);
      Cr_out : out std_logic_vector(9 downto 0);
      Cb_out : out std_logic_vector(9 downto 0)
    );
  end component;

  attribute box_type of demultiplexer_inst_wrapper: component is "black_box";

  component multiplexer_elab_inst_wrapper is
    port (
      reset : in std_logic;
      clock : in std_logic;
      Y_modif : in std_logic_vector(9 downto 0);
      Cr_modif : in std_logic_vector(9 downto 0);
      Cb_modif : in std_logic_vector(9 downto 0);
      Y_in : in std_logic_vector(9 downto 0);
      Cr_in : in std_logic_vector(9 downto 0);
      Cb_in : in std_logic_vector(9 downto 0);
      YCrCb_out : out std_logic_vector(9 downto 0)
    );
  end component;

  attribute box_type of multiplexer_elab_inst_wrapper: component is "black_box";

  component pb_scan_inst_wrapper is
    port (
      clock : in std_logic;
      reset : in std_logic;
      PB_CLOCK_P : in std_logic;
      PB_DATA_P : in std_logic;
      pb1_status : out std_logic;
      pb2_status : out std_logic;
      pb3_status : out std_logic;
      pb4_status : out std_logic;
      pb5_status : out std_logic;
      pb6_status : out std_logic;
      pb7_status : out std_logic;
      pb8_status : out std_logic;
      pb9_status : out std_logic;
      pb10_status : out std_logic
    );
  end component;

  attribute box_type of pb_scan_inst_wrapper: component is "black_box";

  component scal2vect8bit_inst_wrapper is
    port (
      pb3 : in std_logic;
      pb4 : in std_logic;
      pb5 : in std_logic;
      pb6 : in std_logic;
      pb7 : in std_logic;
      pb8 : in std_logic;
      pb9 : in std_logic;
      pb10 : in std_logic;
      pb_vect : out std_logic_vector(7 downto 0)
    );
  end component;

  attribute box_type of scal2vect8bit_inst_wrapper: component is "black_box";

  component IOBUF is
    port (
      I : in std_logic;
      IO : inout std_logic;
      O : out std_logic;
      T : in std_logic
    );
  end component;

  component OBUF is
    port (
      I : in std_logic;
      O : out std_logic
    );
  end component;

  component IBUF is
    port (
      I : in std_logic;
      O : out std_logic
    );
  end component;

  -- Internal signals

  signal Cb_dem_out : std_logic_vector(9 downto 0);
  signal Cb_modif : std_logic_vector(9 downto 0);
  signal Cr_dem_out : std_logic_vector(9 downto 0);
  signal Cr_modif : std_logic_vector(9 downto 0);
  signal Debug_Rst : std_logic;
  signal ENET_SLEW_P_OBUF : std_logic_vector(1 downto 0);
  signal Ext_BRK : std_logic;
  signal Ext_NM_BRK : std_logic;
  signal MDC_P_OBUF : std_logic;
  signal MDIO_P_OBUF : std_logic;
  signal MEMORY_BANK2_ADDR_P_OBUF : std_logic_vector(0 to 18);
  signal MEMORY_BANK2_ADV_LD_N_OBUF : std_logic;
  signal MEMORY_BANK2_CEN_N_OBUF : std_logic;
  signal MEMORY_BANK2_CLKEN_N_OBUF : std_logic;
  signal MEMORY_BANK2_DATA_I : std_logic_vector(0 to 31);
  signal MEMORY_BANK2_DATA_O : std_logic_vector(0 to 31);
  signal MEMORY_BANK2_DATA_T : std_logic;
  signal MEMORY_BANK2_OEN_N_OBUF : std_logic;
  signal MEMORY_BANK2_WEN_N_OBUF : std_logic;
  signal MEMORY_BANK2_WEN_OBUF : std_logic_vector(1 to 4);
  signal PAL_NTSC_N_IBUF : std_logic;
  signal PAUSE_P_OBUF : std_logic;
  signal PB_CLOCK_P_IBUF : std_logic;
  signal PB_DATA_P_IBUF : std_logic;
  signal RS232_RX_DATA_P_IBUF : std_logic;
  signal RS232_TX_DATA_P_OBUF : std_logic;
  signal STARTUP_P_OBUF : std_logic;
  signal S_VIDEO_N_IBUF : std_logic;
  signal USER_INPUT1_P_IBUF : std_logic;
  signal YCRCB_IBUF : std_logic_vector(9 downto 0);
  signal YCRCB_P_OBUF : std_logic_vector(9 downto 0);
  signal YCrCb_in : std_logic_vector(9 downto 0);
  signal Y_dem_out : std_logic_vector(9 downto 0);
  signal Y_modif : std_logic_vector(9 downto 0);
  signal clk_27mhz : std_logic;
  signal clk_81mhz : std_logic;
  signal d_lmb_LMB_ABus : std_logic_vector(0 to 31);
  signal d_lmb_LMB_AddrStrobe : std_logic;
  signal d_lmb_LMB_BE : std_logic_vector(0 to 3);
  signal d_lmb_LMB_ReadDBus : std_logic_vector(0 to 31);
  signal d_lmb_LMB_ReadStrobe : std_logic;
  signal d_lmb_LMB_Ready : std_logic;
  signal d_lmb_LMB_WriteDBus : std_logic_vector(0 to 31);
  signal d_lmb_LMB_WriteStrobe : std_logic;
  signal d_lmb_M_ABus : std_logic_vector(0 to 31);
  signal d_lmb_M_AddrStrobe : std_logic;
  signal d_lmb_M_BE : std_logic_vector(0 to 3);
  signal d_lmb_M_DBus : std_logic_vector(0 to 31);
  signal d_lmb_M_ReadStrobe : std_logic;
  signal d_lmb_M_WriteStrobe : std_logic;
  signal d_lmb_OPB_Rst : std_logic;
  signal d_lmb_Sl_DBus : std_logic_vector(0 to 31);
  signal d_lmb_Sl_Ready : std_logic_vector(0 to 0);
  signal fpga_reset : std_logic;
  signal gpio_data_i2 : std_logic;
  signal gpio_data_i3 : std_logic;
  signal gpio_data_o2 : std_logic;
  signal gpio_data_o3 : std_logic;
  signal gpio_data_o4 : std_logic;
  signal i_lmb_LMB_ABus : std_logic_vector(0 to 31);
  signal i_lmb_LMB_AddrStrobe : std_logic;
  signal i_lmb_LMB_BE : std_logic_vector(0 to 3);
  signal i_lmb_LMB_ReadDBus : std_logic_vector(0 to 31);
  signal i_lmb_LMB_ReadStrobe : std_logic;
  signal i_lmb_LMB_Ready : std_logic;
  signal i_lmb_LMB_WriteDBus : std_logic_vector(0 to 31);
  signal i_lmb_LMB_WriteStrobe : std_logic;
  signal i_lmb_M_ABus : std_logic_vector(0 to 31);
  signal i_lmb_M_AddrStrobe : std_logic;
  signal i_lmb_M_ReadStrobe : std_logic;
  signal i_lmb_OPB_Rst : std_logic;
  signal i_lmb_Sl_DBus : std_logic_vector(0 to 31);
  signal i_lmb_Sl_Ready : std_logic_vector(0 to 0);
  signal line_locked_clock : std_logic;
  signal lmb_porta_BRAM_Addr : std_logic_vector(0 to 31);
  signal lmb_porta_BRAM_Clk : std_logic;
  signal lmb_porta_BRAM_Din : std_logic_vector(0 to 31);
  signal lmb_porta_BRAM_Dout : std_logic_vector(0 to 31);
  signal lmb_porta_BRAM_EN : std_logic;
  signal lmb_porta_BRAM_Rst : std_logic;
  signal lmb_porta_BRAM_WEN : std_logic_vector(0 to 3);
  signal lmb_portb_BRAM_Addr : std_logic_vector(0 to 31);
  signal lmb_portb_BRAM_Clk : std_logic;
  signal lmb_portb_BRAM_Din : std_logic_vector(0 to 31);
  signal lmb_portb_BRAM_Dout : std_logic_vector(0 to 31);
  signal lmb_portb_BRAM_EN : std_logic;
  signal lmb_portb_BRAM_Rst : std_logic;
  signal lmb_portb_BRAM_WEN : std_logic_vector(0 to 3);
  signal myopb_bus_Debug_SYS_Rst : std_logic;
  signal myopb_bus_M_ABus : std_logic_vector(0 to 63);
  signal myopb_bus_M_BE : std_logic_vector(0 to 7);
  signal myopb_bus_M_DBus : std_logic_vector(0 to 63);
  signal myopb_bus_M_RNW : std_logic_vector(0 to 1);
  signal myopb_bus_M_busLock : std_logic_vector(0 to 1);
  signal myopb_bus_M_request : std_logic_vector(0 to 1);
  signal myopb_bus_M_select : std_logic_vector(0 to 1);
  signal myopb_bus_M_seqAddr : std_logic_vector(0 to 1);
  signal myopb_bus_OPB_ABus : std_logic_vector(0 to 31);
  signal myopb_bus_OPB_BE : std_logic_vector(0 to 3);
  signal myopb_bus_OPB_DBus : std_logic_vector(0 to 31);
  signal myopb_bus_OPB_MGrant : std_logic_vector(0 to 1);
  signal myopb_bus_OPB_RNW : std_logic;
  signal myopb_bus_OPB_Rst : std_logic;
  signal myopb_bus_OPB_errAck : std_logic;
  signal myopb_bus_OPB_retry : std_logic;
  signal myopb_bus_OPB_select : std_logic;
  signal myopb_bus_OPB_seqAddr : std_logic;
  signal myopb_bus_OPB_timeout : std_logic;
  signal myopb_bus_OPB_xferAck : std_logic;
  signal myopb_bus_Sl_DBus : std_logic_vector(0 to 255);
  signal myopb_bus_Sl_errAck : std_logic_vector(0 to 7);
  signal myopb_bus_Sl_retry : std_logic_vector(0 to 7);
  signal myopb_bus_Sl_toutSup : std_logic_vector(0 to 7);
  signal myopb_bus_Sl_xferAck : std_logic_vector(0 to 7);
  signal net_gnd0 : std_logic;
  signal net_gnd10 : std_logic_vector(0 to 9);
  signal net_gnd2 : std_logic_vector(0 to 1);
  signal net_gnd32 : std_logic_vector(0 to 31);
  signal net_gnd4 : std_logic_vector(0 to 3);
  signal net_gnd5 : std_logic_vector(0 to 4);
  signal net_gnd8 : std_logic_vector(0 to 7);
  signal net_vcc2 : std_logic_vector(0 to 1);
  signal net_vcc8 : std_logic_vector(0 to 7);
  signal pb : std_logic_vector(0 to 7);
  signal pb10 : std_logic;
  signal pb3 : std_logic;
  signal pb4 : std_logic;
  signal pb5 : std_logic;
  signal pb6 : std_logic;
  signal pb7 : std_logic;
  signal pb8 : std_logic;
  signal pb9 : std_logic;
  signal pixel_data_in : std_logic_vector(9 downto 0);
  signal pixel_data_out : std_logic_vector(9 downto 0);
  signal reset_out : std_logic;
  signal synch_data : std_logic_vector(9 downto 0);

begin

  -- Internal assignments

  net_gnd0 <= '0';
  net_gnd10(0 to 9) <= B"0000000000";
  net_gnd2(0 to 1) <= B"00";
  net_gnd32(0 to 31) <= B"00000000000000000000000000000000";
  net_gnd4(0 to 3) <= B"0000";
  net_gnd5(0 to 4) <= B"00000";
  net_gnd8(0 to 7) <= B"00000000";
  net_vcc2(0 to 1) <= B"11";
  net_vcc8(0 to 7) <= B"11111111";

  microblaze_inst : microblaze_inst_wrapper
    port map (
      CLK => clk_81mhz,
      RESET => fpga_reset,
      INTERRUPT => net_gnd0,
      DEBUG_RST => Debug_Rst,
      EXT_BRK => Ext_BRK,
      EXT_NM_BRK => Ext_NM_BRK,
      DBG_STOP => net_gnd0,
      INSTR => i_lmb_LMB_ReadDBus,
      IREADY => i_lmb_LMB_Ready,
      INSTR_ADDR => i_lmb_M_ABus,
      IFETCH => i_lmb_M_ReadStrobe,
      I_AS => i_lmb_M_AddrStrobe,
      DATA_READ => d_lmb_LMB_ReadDBus,
      DREADY => d_lmb_LMB_Ready,
      DATA_WRITE => d_lmb_M_DBus,
      DATA_ADDR => d_lmb_M_ABus,
      D_AS => d_lmb_M_AddrStrobe,
      READ_STROBE => d_lmb_M_ReadStrobe,
      WRITE_STROBE => d_lmb_M_WriteStrobe,
      BYTE_ENABLE => d_lmb_M_BE,
      DM_ABUS => myopb_bus_M_ABus(0 to 31),
      DM_BE => myopb_bus_M_BE(0 to 3),
      DM_BUSLOCK => myopb_bus_M_busLock(0),
      DM_DBUS => myopb_bus_M_DBus(0 to 31),
      DM_REQUEST => myopb_bus_M_request(0),
      DM_RNW => myopb_bus_M_RNW(0),
      DM_SELECT => myopb_bus_M_select(0),
      DM_SEQADDR => myopb_bus_M_seqAddr(0),
      DOPB_DBUS => myopb_bus_OPB_DBus,
      DOPB_ERRACK => myopb_bus_OPB_errAck,
      DOPB_MGRANT => myopb_bus_OPB_MGrant(0),
      DOPB_RETRY => myopb_bus_OPB_retry,
      DOPB_TIMEOUT => myopb_bus_OPB_timeout,
      DOPB_XFERACK => myopb_bus_OPB_xferAck,
      IM_ABUS => myopb_bus_M_ABus(32 to 63),
      IM_BE => myopb_bus_M_BE(4 to 7),
      IM_BUSLOCK => myopb_bus_M_busLock(1),
      IM_DBUS => myopb_bus_M_DBus(32 to 63),
      IM_REQUEST => myopb_bus_M_request(1),
      IM_RNW => myopb_bus_M_RNW(1),
      IM_SELECT => myopb_bus_M_select(1),
      IM_SEQADDR => myopb_bus_M_seqAddr(1),
      IOPB_DBUS => myopb_bus_OPB_DBus,
      IOPB_ERRACK => myopb_bus_OPB_errAck,
      IOPB_MGRANT => myopb_bus_OPB_MGrant(1),
      IOPB_RETRY => myopb_bus_OPB_retry,
      IOPB_TIMEOUT => myopb_bus_OPB_timeout,
      IOPB_XFERACK => myopb_bus_OPB_xferAck,
      DBG_CLK => net_gnd0,
      DBG_TDI => net_gnd0,
      DBG_TDO => open,
      DBG_REG_EN => net_gnd5,
      DBG_CAPTURE => net_gnd0,
      DBG_UPDATE => net_gnd0,
      VALID_INSTR => open,
      PC_EX => open,
      REG_WRITE => open,
      REG_ADDR => open,
      MSR_REG => open,
      NEW_REG_VALUE => open,
      PIPE_RUNNING => open,
      INTERRUPT_TAKEN => open,
      JUMP_TAKEN => open,
      PREFETCH_ADDR => open,
      MB_Halted => open,
      FSL0_S_CLK => open,
      FSL0_S_READ => open,
      FSL0_S_DATA => net_gnd32,
      FSL0_S_CONTROL => net_gnd0,
      FSL0_S_EXISTS => net_gnd0,
      FSL0_M_CLK => open,
      FSL0_M_WRITE => open,
      FSL0_M_DATA => open,
      FSL0_M_CONTROL => open,
      FSL0_M_FULL => net_gnd0,
      FSL1_S_CLK => open,
      FSL1_S_READ => open,
      FSL1_S_DATA => net_gnd32,
      FSL1_S_CONTROL => net_gnd0,
      FSL1_S_EXISTS => net_gnd0,
      FSL1_M_CLK => open,
      FSL1_M_WRITE => open,
      FSL1_M_DATA => open,
      FSL1_M_CONTROL => open,
      FSL1_M_FULL => net_gnd0,
      FSL2_S_CLK => open,
      FSL2_S_READ => open,
      FSL2_S_DATA => net_gnd32,
      FSL2_S_CONTROL => net_gnd0,
      FSL2_S_EXISTS => net_gnd0,
      FSL2_M_CLK => open,
      FSL2_M_WRITE => open,
      FSL2_M_DATA => open,
      FSL2_M_CONTROL => open,
      FSL2_M_FULL => net_gnd0,
      FSL3_S_CLK => open,
      FSL3_S_READ => open,
      FSL3_S_DATA => net_gnd32,
      FSL3_S_CONTROL => net_gnd0,
      FSL3_S_EXISTS => net_gnd0,
      FSL3_M_CLK => open,
      FSL3_M_WRITE => open,
      FSL3_M_DATA => open,
      FSL3_M_CONTROL => open,
      FSL3_M_FULL => net_gnd0,
      FSL4_S_CLK => open,
      FSL4_S_READ => open,
      FSL4_S_DATA => net_gnd32,
      FSL4_S_CONTROL => net_gnd0,
      FSL4_S_EXISTS => net_gnd0,
      FSL4_M_CLK => open,
      FSL4_M_WRITE => open,
      FSL4_M_DATA => open,
      FSL4_M_CONTROL => open,
      FSL4_M_FULL => net_gnd0,
      FSL5_S_CLK => open,
      FSL5_S_READ => open,
      FSL5_S_DATA => net_gnd32,
      FSL5_S_CONTROL => net_gnd0,
      FSL5_S_EXISTS => net_gnd0,
      FSL5_M_CLK => open,
      FSL5_M_WRITE => open,
      FSL5_M_DATA => open,
      FSL5_M_CONTROL => open,
      FSL5_M_FULL => net_gnd0,
      FSL6_S_CLK => open,
      FSL6_S_READ => open,
      FSL6_S_DATA => net_gnd32,
      FSL6_S_CONTROL => net_gnd0,
      FSL6_S_EXISTS => net_gnd0,
      FSL6_M_CLK => open,
      FSL6_M_WRITE => open,
      FSL6_M_DATA => open,
      FSL6_M_CONTROL => open,
      FSL6_M_FULL => net_gnd0,
      FSL7_S_CLK => open,
      FSL7_S_READ => open,
      FSL7_S_DATA => net_gnd32,
      FSL7_S_CONTROL => net_gnd0,
      FSL7_S_EXISTS => net_gnd0,
      FSL7_M_CLK => open,
      FSL7_M_WRITE => open,
      FSL7_M_DATA => open,
      FSL7_M_CONTROL => open,
      FSL7_M_FULL => net_gnd0
    );

  d_lmb : d_lmb_wrapper
    port map (
      LMB_Clk => clk_81mhz,
      SYS_Rst => fpga_reset,
      LMB_Rst => d_lmb_OPB_Rst,
      M_ABus => d_lmb_M_ABus,
      M_ReadStrobe => d_lmb_M_ReadStrobe,
      M_WriteStrobe => d_lmb_M_WriteStrobe,
      M_AddrStrobe => d_lmb_M_AddrStrobe,
      M_DBus => d_lmb_M_DBus,
      M_BE => d_lmb_M_BE,
      Sl_DBus => d_lmb_Sl_DBus,
      Sl_Ready => d_lmb_Sl_Ready(0 to 0),
      LMB_ABus => d_lmb_LMB_ABus,
      LMB_ReadStrobe => d_lmb_LMB_ReadStrobe,
      LMB_WriteStrobe => d_lmb_LMB_WriteStrobe,
      LMB_AddrStrobe => d_lmb_LMB_AddrStrobe,
      LMB_ReadDBus => d_lmb_LMB_ReadDBus,
      LMB_WriteDBus => d_lmb_LMB_WriteDBus,
      LMB_Ready => d_lmb_LMB_Ready,
      LMB_BE => d_lmb_LMB_BE
    );

  i_lmb : i_lmb_wrapper
    port map (
      LMB_Clk => clk_81mhz,
      SYS_Rst => fpga_reset,
      LMB_Rst => i_lmb_OPB_Rst,
      M_ABus => i_lmb_M_ABus,
      M_ReadStrobe => i_lmb_M_ReadStrobe,
      M_WriteStrobe => net_gnd0,
      M_AddrStrobe => i_lmb_M_AddrStrobe,
      M_DBus => net_gnd32,
      M_BE => net_gnd4,
      Sl_DBus => i_lmb_Sl_DBus,
      Sl_Ready => i_lmb_Sl_Ready(0 to 0),
      LMB_ABus => i_lmb_LMB_ABus,
      LMB_ReadStrobe => i_lmb_LMB_ReadStrobe,
      LMB_WriteStrobe => i_lmb_LMB_WriteStrobe,
      LMB_AddrStrobe => i_lmb_LMB_AddrStrobe,
      LMB_ReadDBus => i_lmb_LMB_ReadDBus,
      LMB_WriteDBus => i_lmb_LMB_WriteDBus,
      LMB_Ready => i_lmb_LMB_Ready,
      LMB_BE => i_lmb_LMB_BE
    );

  myopb_bus : myopb_bus_wrapper
    port map (
      OPB_Clk => clk_81mhz,
      OPB_Rst => myopb_bus_OPB_Rst,
      SYS_Rst => fpga_reset,
      Debug_SYS_Rst => myopb_bus_Debug_SYS_Rst,
      WDT_Rst => net_gnd0,
      M_ABus => myopb_bus_M_ABus,
      M_BE => myopb_bus_M_BE,
      M_beXfer => net_gnd2,
      M_busLock => myopb_bus_M_busLock,
      M_DBus => myopb_bus_M_DBus,
      M_DBusEn => net_gnd2,
      M_DBusEn32_63 => net_vcc2,
      M_dwXfer => net_gnd2,
      M_fwXfer => net_gnd2,
      M_hwXfer => net_gnd2,
      M_request => myopb_bus_M_request,
      M_RNW => myopb_bus_M_RNW,
      M_select => myopb_bus_M_select,
      M_seqAddr => myopb_bus_M_seqAddr,
      Sl_beAck => net_gnd8,
      Sl_DBus => myopb_bus_Sl_DBus,
      Sl_DBusEn => net_vcc8,
      Sl_DBusEn32_63 => net_vcc8,
      Sl_errAck => myopb_bus_Sl_errAck,
      Sl_dwAck => net_gnd8,
      Sl_fwAck => net_gnd8,
      Sl_hwAck => net_gnd8,
      Sl_retry => myopb_bus_Sl_retry,
      Sl_toutSup => myopb_bus_Sl_toutSup,
      Sl_xferAck => myopb_bus_Sl_xferAck,
      OPB_MRequest => open,
      OPB_ABus => myopb_bus_OPB_ABus,
      OPB_BE => myopb_bus_OPB_BE,
      OPB_beXfer => open,
      OPB_beAck => open,
      OPB_busLock => open,
      OPB_rdDBus => open,
      OPB_wrDBus => open,
      OPB_DBus => myopb_bus_OPB_DBus,
      OPB_errAck => myopb_bus_OPB_errAck,
      OPB_dwAck => open,
      OPB_dwXfer => open,
      OPB_fwAck => open,
      OPB_fwXfer => open,
      OPB_hwAck => open,
      OPB_hwXfer => open,
      OPB_MGrant => myopb_bus_OPB_MGrant,
      OPB_pendReq => open,
      OPB_retry => myopb_bus_OPB_retry,
      OPB_RNW => myopb_bus_OPB_RNW,
      OPB_select => myopb_bus_OPB_select,
      OPB_seqAddr => myopb_bus_OPB_seqAddr,
      OPB_timeout => myopb_bus_OPB_timeout,
      OPB_toutSup => open,
      OPB_xferAck => myopb_bus_OPB_xferAck
    );

  dlmb_cntlr : dlmb_cntlr_wrapper
    port map (
      LMB_Clk => clk_81mhz,
      LMB_Rst => d_lmb_OPB_Rst,
      LMB_ABus => d_lmb_LMB_ABus,
      LMB_WriteDBus => d_lmb_LMB_WriteDBus,
      LMB_AddrStrobe => d_lmb_LMB_AddrStrobe,
      LMB_ReadStrobe => d_lmb_LMB_ReadStrobe,
      LMB_WriteStrobe => d_lmb_LMB_WriteStrobe,
      LMB_BE => d_lmb_LMB_BE,
      Sl_DBus => d_lmb_Sl_DBus,
      Sl_Ready => d_lmb_Sl_Ready(0),
      BRAM_Rst_A => lmb_porta_BRAM_Rst,
      BRAM_Clk_A => lmb_porta_BRAM_Clk,
      BRAM_EN_A => lmb_porta_BRAM_EN,
      BRAM_WEN_A => lmb_porta_BRAM_WEN,
      BRAM_Addr_A => lmb_porta_BRAM_Addr,
      BRAM_Din_A => lmb_porta_BRAM_Din,
      BRAM_Dout_A => lmb_porta_BRAM_Dout
    );

  ilmb_cntlr : ilmb_cntlr_wrapper
    port map (
      LMB_Clk => clk_81mhz,
      LMB_Rst => i_lmb_OPB_Rst,
      LMB_ABus => i_lmb_LMB_ABus,
      LMB_WriteDBus => i_lmb_LMB_WriteDBus,
      LMB_AddrStrobe => i_lmb_LMB_AddrStrobe,
      LMB_ReadStrobe => i_lmb_LMB_ReadStrobe,
      LMB_WriteStrobe => i_lmb_LMB_WriteStrobe,
      LMB_BE => i_lmb_LMB_BE,
      Sl_DBus => i_lmb_Sl_DBus,
      Sl_Ready => i_lmb_Sl_Ready(0),
      BRAM_Rst_A => lmb_portb_BRAM_Rst,
      BRAM_Clk_A => lmb_portb_BRAM_Clk,
      BRAM_EN_A => lmb_portb_BRAM_EN,
      BRAM_WEN_A => lmb_portb_BRAM_WEN,
      BRAM_Addr_A => lmb_portb_BRAM_Addr,
      BRAM_Din_A => lmb_portb_BRAM_Din,
      BRAM_Dout_A => lmb_portb_BRAM_Dout
    );

  bram_inst : bram_inst_wrapper
    port map (
      BRAM_Rst_A => lmb_porta_BRAM_Rst,
      BRAM_Clk_A => lmb_porta_BRAM_Clk,
      BRAM_EN_A => lmb_porta_BRAM_EN,
      BRAM_WEN_A => lmb_porta_BRAM_WEN,
      BRAM_Addr_A => lmb_porta_BRAM_Addr,
      BRAM_Din_A => lmb_porta_BRAM_Din,
      BRAM_Dout_A => lmb_porta_BRAM_Dout,
      BRAM_Rst_B => lmb_portb_BRAM_Rst,
      BRAM_Clk_B => lmb_portb_BRAM_Clk,
      BRAM_EN_B => lmb_portb_BRAM_EN,
      BRAM_WEN_B => lmb_portb_BRAM_WEN,
      BRAM_Addr_B => lmb_portb_BRAM_Addr,
      BRAM_Din_B => lmb_portb_BRAM_Din,
      BRAM_Dout_B => lmb_portb_BRAM_Dout
    );

  zbt_cntlr : zbt_cntlr_wrapper
    port map (
      OPB_Clk => clk_81mhz,
      OPB_Rst => fpga_reset,
      OPB_ABus => myopb_bus_OPB_ABus,
      OPB_BE => myopb_bus_OPB_BE,
      OPB_RNW => myopb_bus_OPB_RNW,
      OPB_select => myopb_bus_OPB_select,
      OPB_seqAddr => myopb_bus_OPB_seqAddr,
      OPB_DBus => myopb_bus_OPB_DBus,
      ZBT_DBus => myopb_bus_Sl_DBus(0 to 31),
      ZBT_errAck => myopb_bus_Sl_errAck(0),
      ZBT_retry => myopb_bus_Sl_retry(0),
      ZBT_toutSup => myopb_bus_Sl_toutSup(0),
      ZBT_xferAck => myopb_bus_Sl_xferAck(0),
      ZBT_Clk_FB => net_gnd0,
      ZBT_Clk_FBOut => open,
      ZBT_Clk => open,
      ZBT_OE_N => MEMORY_BANK2_OEN_N_OBUF,
      ZBT_ADV_LD_N => MEMORY_BANK2_ADV_LD_N_OBUF,
      ZBT_LBO_N => open,
      ZBT_CE1_N => MEMORY_BANK2_CEN_N_OBUF,
      ZBT_CE2_N => open,
      ZBT_CE2 => open,
      ZBT_RW_N => MEMORY_BANK2_WEN_N_OBUF,
      ZBT_CKE_N => MEMORY_BANK2_CLKEN_N_OBUF,
      ZBT_A => MEMORY_BANK2_ADDR_P_OBUF,
      ZBT_BW_N => MEMORY_BANK2_WEN_OBUF,
      ZBT_IO_I => MEMORY_BANK2_DATA_I,
      ZBT_IO_O => MEMORY_BANK2_DATA_O,
      ZBT_IO_T => MEMORY_BANK2_DATA_T,
      ZBT_IOP_I => net_gnd4,
      ZBT_IOP_O => open,
      ZBT_IOP_T => open
    );

  jtag_inst : jtag_inst_wrapper
    port map (
      OPB_Clk => clk_81mhz,
      OPB_Rst => myopb_bus_OPB_Rst,
      Interrupt => open,
      Debug_SYS_Rst => myopb_bus_Debug_SYS_Rst,
      Debug_Rst => Debug_Rst,
      Ext_BRK => Ext_BRK,
      Ext_NM_BRK => Ext_NM_BRK,
      OPB_ABus => myopb_bus_OPB_ABus,
      OPB_BE => myopb_bus_OPB_BE,
      OPB_RNW => myopb_bus_OPB_RNW,
      OPB_select => myopb_bus_OPB_select,
      OPB_seqAddr => myopb_bus_OPB_seqAddr,
      OPB_DBus => myopb_bus_OPB_DBus,
      JTAG_UART_DBus => myopb_bus_Sl_DBus(32 to 63),
      JTAG_UART_errAck => myopb_bus_Sl_errAck(1),
      JTAG_UART_retry => myopb_bus_Sl_retry(1),
      JTAG_UART_toutSup => myopb_bus_Sl_toutSup(1),
      JTAG_UART_xferAck => myopb_bus_Sl_xferAck(1)
    );

  uart_inst : uart_inst_wrapper
    port map (
      OPB_Clk => clk_81mhz,
      OPB_Rst => myopb_bus_OPB_Rst,
      Interrupt => open,
      OPB_ABus => myopb_bus_OPB_ABus,
      OPB_BE => myopb_bus_OPB_BE,
      OPB_RNW => myopb_bus_OPB_RNW,
      OPB_select => myopb_bus_OPB_select,
      OPB_seqAddr => myopb_bus_OPB_seqAddr,
      OPB_DBus => myopb_bus_OPB_DBus,
      UART_DBus => myopb_bus_Sl_DBus(64 to 95),
      UART_errAck => myopb_bus_Sl_errAck(2),
      UART_retry => myopb_bus_Sl_retry(2),
      UART_toutSup => myopb_bus_Sl_toutSup(2),
      UART_xferAck => myopb_bus_Sl_xferAck(2),
      RX => RS232_RX_DATA_P_IBUF,
      TX => RS232_TX_DATA_P_OBUF
    );

  gpio_button_in : gpio_button_in_wrapper
    port map (
      OPB_ABus => myopb_bus_OPB_ABus,
      OPB_BE => myopb_bus_OPB_BE,
      OPB_Clk => clk_81mhz,
      OPB_DBus => myopb_bus_OPB_DBus,
      OPB_RNW => myopb_bus_OPB_RNW,
      OPB_Rst => myopb_bus_OPB_Rst,
      OPB_select => myopb_bus_OPB_select,
      OPB_seqAddr => myopb_bus_OPB_seqAddr,
      Sln_DBus => myopb_bus_Sl_DBus(96 to 127),
      Sln_errAck => myopb_bus_Sl_errAck(3),
      Sln_retry => myopb_bus_Sl_retry(3),
      Sln_toutSup => myopb_bus_Sl_toutSup(3),
      Sln_xferAck => myopb_bus_Sl_xferAck(3),
      Device_Intr => open,
      GPIO_in => pb,
      GPIO_d_out => open,
      GPIO_t_out => open,
      GPIO2_in => net_gnd8,
      GPIO2_d_out => open,
      GPIO2_t_out => open,
      GPIO_IO_I => net_gnd8,
      GPIO_IO_O => open,
      GPIO_IO_T => open,
      GPIO2_IO_I => net_gnd8,
      GPIO2_IO_O => open,
      GPIO2_IO_T => open
    );

  gpio_y : gpio_y_wrapper
    port map (
      OPB_ABus => myopb_bus_OPB_ABus,
      OPB_BE => myopb_bus_OPB_BE,
      OPB_Clk => clk_81mhz,
      OPB_DBus => myopb_bus_OPB_DBus,
      OPB_RNW => myopb_bus_OPB_RNW,
      OPB_Rst => myopb_bus_OPB_Rst,
      OPB_select => myopb_bus_OPB_select,
      OPB_seqAddr => myopb_bus_OPB_seqAddr,
      Sln_DBus => myopb_bus_Sl_DBus(128 to 159),
      Sln_errAck => myopb_bus_Sl_errAck(4),
      Sln_retry => myopb_bus_Sl_retry(4),
      Sln_toutSup => myopb_bus_Sl_toutSup(4),
      Sln_xferAck => myopb_bus_Sl_xferAck(4),
      Device_Intr => open,
      GPIO_in => net_gnd10,
      GPIO_d_out => Y_modif(9 downto 0),
      GPIO_t_out => open,
      GPIO2_in => net_gnd10,
      GPIO2_d_out => open,
      GPIO2_t_out => open,
      GPIO_IO_I => net_gnd10,
      GPIO_IO_O => open,
      GPIO_IO_T => open,
      GPIO2_IO_I => net_gnd10,
      GPIO2_IO_O => open,
      GPIO2_IO_T => open
    );

  gpio_cr : gpio_cr_wrapper
    port map (
      OPB_ABus => myopb_bus_OPB_ABus,
      OPB_BE => myopb_bus_OPB_BE,
      OPB_Clk => clk_81mhz,
      OPB_DBus => myopb_bus_OPB_DBus,
      OPB_RNW => myopb_bus_OPB_RNW,
      OPB_Rst => myopb_bus_OPB_Rst,
      OPB_select => myopb_bus_OPB_select,
      OPB_seqAddr => myopb_bus_OPB_seqAddr,
      Sln_DBus => myopb_bus_Sl_DBus(160 to 191),
      Sln_errAck => myopb_bus_Sl_errAck(5),
      Sln_retry => myopb_bus_Sl_retry(5),
      Sln_toutSup => myopb_bus_Sl_toutSup(5),
      Sln_xferAck => myopb_bus_Sl_xferAck(5),
      Device_Intr => open,
      GPIO_in => net_gnd10,
      GPIO_d_out => Cr_modif(9 downto 0),
      GPIO_t_out => open,
      GPIO2_in => net_gnd10,
      GPIO2_d_out => open,
      GPIO2_t_out => open,
      GPIO_IO_I => net_gnd10,
      GPIO_IO_O => open,
      GPIO_IO_T => open,
      GPIO2_IO_I => net_gnd10,
      GPIO2_IO_O => open,
      GPIO2_IO_T => open
    );

  gpio_cb : gpio_cb_wrapper
    port map (
      OPB_ABus => myopb_bus_OPB_ABus,
      OPB_BE => myopb_bus_OPB_BE,
      OPB_Clk => clk_81mhz,
      OPB_DBus => myopb_bus_OPB_DBus,
      OPB_RNW => myopb_bus_OPB_RNW,
      OPB_Rst => myopb_bus_OPB_Rst,
      OPB_select => myopb_bus_OPB_select,
      OPB_seqAddr => myopb_bus_OPB_seqAddr,
      Sln_DBus => myopb_bus_Sl_DBus(192 to 223),
      Sln_errAck => myopb_bus_Sl_errAck(6),
      Sln_retry => myopb_bus_Sl_retry(6),
      Sln_toutSup => myopb_bus_Sl_toutSup(6),
      Sln_xferAck => myopb_bus_Sl_xferAck(6),
      Device_Intr => open,
      GPIO_in => net_gnd10,
      GPIO_d_out => Cb_modif(9 downto 0),
      GPIO_t_out => open,
      GPIO2_in => net_gnd10,
      GPIO2_d_out => open,
      GPIO2_t_out => open,
      GPIO_IO_I => net_gnd10,
      GPIO_IO_O => open,
      GPIO_IO_T => open,
      GPIO2_IO_I => net_gnd10,
      GPIO2_IO_O => open,
      GPIO2_IO_T => open
    );

  clock_gen_inst : clock_gen_inst_wrapper
    port map (
      master_clock_p => MASTER_CLOCK_P,
      line_locked_clock1 => LINE_LOCKED_CLOCK1,
      extend_dcm_reset_p => EXTEND_DCM_RESET_P,
      memory_bank2_clk_p => MEMORY_BANK2_CLK_P,
      clk_27mhz => clk_27mhz,
      line_locked_clock => line_locked_clock,
      clk_81mhz => clk_81mhz,
      fpga_reset => fpga_reset,
      enet_slew_p => ENET_SLEW_P_OBUF,
      pause_p => PAUSE_P_OBUF,
      mdio_p => MDIO_P_OBUF,
      mdc_p => MDC_P_OBUF,
      startup_p => STARTUP_P_OBUF
    );

  gpio_mod_inst : gpio_mod_inst_wrapper
    port map (
      OPB_Clk => clk_81mhz,
      OPB_Rst => fpga_reset,
      OPB_ABus => myopb_bus_OPB_ABus,
      OPB_BE => myopb_bus_OPB_BE,
      OPB_DBus => myopb_bus_OPB_DBus,
      OPB_RNW => myopb_bus_OPB_RNW,
      OPB_select => myopb_bus_OPB_select,
      OPB_seqAddr => myopb_bus_OPB_seqAddr,
      GPIO_DBus => myopb_bus_Sl_DBus(224 to 255),
      GPIO_errAck => myopb_bus_Sl_errAck(7),
      GPIO_retry => myopb_bus_Sl_retry(7),
      GPIO_toutSup => myopb_bus_Sl_toutSup(7),
      GPIO_xferAck => myopb_bus_Sl_xferAck(7),
      GPIO_IO_I0 => net_gnd0,
      GPIO_IO_I1 => net_gnd0,
      GPIO_IO_I2 => gpio_data_i2,
      GPIO_IO_I3 => gpio_data_i3,
      GPIO_IO_I4 => net_gnd0,
      GPIO_IO_I5 => net_gnd0,
      GPIO_IO_I6 => net_gnd0,
      GPIO_IO_I7 => net_gnd0,
      GPIO_IO_I8 => net_gnd0,
      GPIO_IO_I9 => net_gnd0,
      GPIO_IO_I10 => net_gnd0,
      GPIO_IO_I11 => net_gnd0,
      GPIO_IO_I12 => net_gnd0,
      GPIO_IO_I13 => PAL_NTSC_N_IBUF,
      GPIO_IO_I14 => S_VIDEO_N_IBUF,
      GPIO_IO_I15 => USER_INPUT1_P_IBUF,
      GPIO_IO_O0 => open,
      GPIO_IO_O1 => open,
      GPIO_IO_O2 => gpio_data_o2,
      GPIO_IO_O3 => gpio_data_o3,
      GPIO_IO_O4 => gpio_data_o4,
      GPIO_IO_O5 => open,
      GPIO_IO_O6 => open,
      GPIO_IO_O7 => open,
      GPIO_IO_O8 => open,
      GPIO_IO_O9 => open,
      GPIO_IO_O10 => open,
      GPIO_IO_O11 => open,
      GPIO_IO_O12 => open,
      GPIO_IO_O13 => open,
      GPIO_IO_O14 => open,
      GPIO_IO_O15 => open
    );

  gpio2iic_inst : gpio2iic_inst_wrapper
    port map (
      gpio_data_i2 => gpio_data_i2,
      gpio_data_i3 => gpio_data_i3,
      gpio_data_o2 => gpio_data_o2,
      gpio_data_o3 => gpio_data_o3,
      gpio_data_o4 => gpio_data_o4,
      video_encoder_sclk_p => VIDEO_ENCODER_SCLK_P,
      video_encoder_data_p => VIDEO_ENCODER_DATA_P,
      i2c_clock_p => I2C_CLOCK_P,
      i2c_data_p => I2C_DATA_P
    );

  vid_resync_buf_inst : vid_resync_buf_inst_wrapper
    port map (
      vid_27mhz_input_clock => line_locked_clock,
      vid_27mhz_output_clock => clk_27mhz,
      reset => fpga_reset,
      YCrCb_input => YCRCB_IBUF,
      YCrCb_reg_out => YCrCb_in
    );

  video_block_inst : video_block_inst_wrapper
    port map (
      reset => fpga_reset,
      clock => clk_27mhz,
      YCrCb_in => YCrCb_in,
      pixel_data_in => pixel_data_in,
      synch_data_in => synch_data,
      YCrCb_out => YCRCB_P_OBUF,
      pixel_data_out => pixel_data_out,
      synch_data_out => synch_data,
      reset_out => reset_out
    );

  demultiplexer_inst : demultiplexer_inst_wrapper
    port map (
      reset => reset_out,
      clock => clk_27mhz,
      YCrCb_in => pixel_data_out,
      Y_out => Y_dem_out,
      Cr_out => Cr_dem_out,
      Cb_out => Cb_dem_out
    );

  multiplexer_elab_inst : multiplexer_elab_inst_wrapper
    port map (
      reset => fpga_reset,
      clock => clk_27mhz,
      Y_modif => Y_modif,
      Cr_modif => Cr_modif,
      Cb_modif => Cb_modif,
      Y_in => Y_dem_out,
      Cr_in => Cr_dem_out,
      Cb_in => Cb_dem_out,
      YCrCb_out => pixel_data_in
    );

  pb_scan_inst : pb_scan_inst_wrapper
    port map (
      clock => clk_27mhz,
      reset => fpga_reset,
      PB_CLOCK_P => PB_CLOCK_P_IBUF,
      PB_DATA_P => PB_DATA_P_IBUF,
      pb1_status => open,
      pb2_status => open,
      pb3_status => pb3,
      pb4_status => pb4,
      pb5_status => pb5,
      pb6_status => pb6,
      pb7_status => pb7,
      pb8_status => pb8,
      pb9_status => pb9,
      pb10_status => pb10
    );

  scal2vect8bit_inst : scal2vect8bit_inst_wrapper
    port map (
      pb3 => pb3,
      pb4 => pb4,
      pb5 => pb5,
      pb6 => pb6,
      pb7 => pb7,
      pb8 => pb8,
      pb9 => pb9,
      pb10 => pb10,
      pb_vect => pb(0 to 7)
    );

  iobuf_0 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(0),
      IO => MEMORY_BANK2_DATA(0),
      O => MEMORY_BANK2_DATA_I(0),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_1 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(1),
      IO => MEMORY_BANK2_DATA(1),
      O => MEMORY_BANK2_DATA_I(1),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_2 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(2),
      IO => MEMORY_BANK2_DATA(2),
      O => MEMORY_BANK2_DATA_I(2),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_3 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(3),
      IO => MEMORY_BANK2_DATA(3),
      O => MEMORY_BANK2_DATA_I(3),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_4 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(4),
      IO => MEMORY_BANK2_DATA(4),
      O => MEMORY_BANK2_DATA_I(4),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_5 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(5),
      IO => MEMORY_BANK2_DATA(5),
      O => MEMORY_BANK2_DATA_I(5),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_6 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(6),
      IO => MEMORY_BANK2_DATA(6),
      O => MEMORY_BANK2_DATA_I(6),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_7 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(7),
      IO => MEMORY_BANK2_DATA(7),
      O => MEMORY_BANK2_DATA_I(7),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_8 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(8),
      IO => MEMORY_BANK2_DATA(8),
      O => MEMORY_BANK2_DATA_I(8),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_9 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(9),
      IO => MEMORY_BANK2_DATA(9),
      O => MEMORY_BANK2_DATA_I(9),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_10 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(10),
      IO => MEMORY_BANK2_DATA(10),
      O => MEMORY_BANK2_DATA_I(10),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_11 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(11),
      IO => MEMORY_BANK2_DATA(11),
      O => MEMORY_BANK2_DATA_I(11),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_12 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(12),
      IO => MEMORY_BANK2_DATA(12),
      O => MEMORY_BANK2_DATA_I(12),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_13 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(13),
      IO => MEMORY_BANK2_DATA(13),
      O => MEMORY_BANK2_DATA_I(13),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_14 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(14),
      IO => MEMORY_BANK2_DATA(14),
      O => MEMORY_BANK2_DATA_I(14),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_15 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(15),
      IO => MEMORY_BANK2_DATA(15),
      O => MEMORY_BANK2_DATA_I(15),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_16 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(16),
      IO => MEMORY_BANK2_DATA(16),
      O => MEMORY_BANK2_DATA_I(16),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_17 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(17),
      IO => MEMORY_BANK2_DATA(17),
      O => MEMORY_BANK2_DATA_I(17),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_18 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(18),
      IO => MEMORY_BANK2_DATA(18),
      O => MEMORY_BANK2_DATA_I(18),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_19 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(19),
      IO => MEMORY_BANK2_DATA(19),
      O => MEMORY_BANK2_DATA_I(19),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_20 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(20),
      IO => MEMORY_BANK2_DATA(20),
      O => MEMORY_BANK2_DATA_I(20),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_21 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(21),
      IO => MEMORY_BANK2_DATA(21),
      O => MEMORY_BANK2_DATA_I(21),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_22 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(22),
      IO => MEMORY_BANK2_DATA(22),
      O => MEMORY_BANK2_DATA_I(22),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_23 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(23),
      IO => MEMORY_BANK2_DATA(23),
      O => MEMORY_BANK2_DATA_I(23),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_24 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(24),
      IO => MEMORY_BANK2_DATA(24),
      O => MEMORY_BANK2_DATA_I(24),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_25 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(25),
      IO => MEMORY_BANK2_DATA(25),
      O => MEMORY_BANK2_DATA_I(25),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_26 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(26),
      IO => MEMORY_BANK2_DATA(26),
      O => MEMORY_BANK2_DATA_I(26),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_27 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(27),
      IO => MEMORY_BANK2_DATA(27),
      O => MEMORY_BANK2_DATA_I(27),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_28 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(28),
      IO => MEMORY_BANK2_DATA(28),
      O => MEMORY_BANK2_DATA_I(28),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_29 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(29),
      IO => MEMORY_BANK2_DATA(29),
      O => MEMORY_BANK2_DATA_I(29),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_30 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(30),
      IO => MEMORY_BANK2_DATA(30),
      O => MEMORY_BANK2_DATA_I(30),
      T => MEMORY_BANK2_DATA_T
    );

  iobuf_31 : IOBUF
    port map (
      I => MEMORY_BANK2_DATA_O(31),
      IO => MEMORY_BANK2_DATA(31),
      O => MEMORY_BANK2_DATA_I(31),
      T => MEMORY_BANK2_DATA_T
    );

  obuf_32 : OBUF
    port map (
      I => MEMORY_BANK2_CLKEN_N_OBUF,
      O => MEMORY_BANK2_CLKEN_N
    );

  obuf_33 : OBUF
    port map (
      I => MEMORY_BANK2_CEN_N_OBUF,
      O => MEMORY_BANK2_CEN_N
    );

  obuf_34 : OBUF
    port map (
      I => MEMORY_BANK2_OEN_N_OBUF,
      O => MEMORY_BANK2_OEN_N
    );

  obuf_35 : OBUF
    port map (
      I => MEMORY_BANK2_WEN_OBUF(1),
      O => MEMORY_BANK2_WEN(1)
    );

  obuf_36 : OBUF
    port map (
      I => MEMORY_BANK2_WEN_OBUF(2),
      O => MEMORY_BANK2_WEN(2)
    );

  obuf_37 : OBUF
    port map (
      I => MEMORY_BANK2_WEN_OBUF(3),
      O => MEMORY_BANK2_WEN(3)
    );

  obuf_38 : OBUF
    port map (
      I => MEMORY_BANK2_WEN_OBUF(4),
      O => MEMORY_BANK2_WEN(4)
    );

  obuf_39 : OBUF
    port map (
      I => MEMORY_BANK2_WEN_N_OBUF,
      O => MEMORY_BANK2_WEN_N
    );

  obuf_40 : OBUF
    port map (
      I => MEMORY_BANK2_ADV_LD_N_OBUF,
      O => MEMORY_BANK2_ADV_LD_N
    );

  obuf_41 : OBUF
    port map (
      I => MEMORY_BANK2_ADDR_P_OBUF(0),
      O => MEMORY_BANK2_ADDR_P(0)
    );

  obuf_42 : OBUF
    port map (
      I => MEMORY_BANK2_ADDR_P_OBUF(1),
      O => MEMORY_BANK2_ADDR_P(1)
    );

  obuf_43 : OBUF
    port map (
      I => MEMORY_BANK2_ADDR_P_OBUF(2),
      O => MEMORY_BANK2_ADDR_P(2)
    );

  obuf_44 : OBUF
    port map (
      I => MEMORY_BANK2_ADDR_P_OBUF(3),
      O => MEMORY_BANK2_ADDR_P(3)
    );

  obuf_45 : OBUF
    port map (
      I => MEMORY_BANK2_ADDR_P_OBUF(4),
      O => MEMORY_BANK2_ADDR_P(4)
    );

  obuf_46 : OBUF
    port map (
      I => MEMORY_BANK2_ADDR_P_OBUF(5),
      O => MEMORY_BANK2_ADDR_P(5)
    );

  obuf_47 : OBUF
    port map (
      I => MEMORY_BANK2_ADDR_P_OBUF(6),
      O => MEMORY_BANK2_ADDR_P(6)
    );

  obuf_48 : OBUF
    port map (
      I => MEMORY_BANK2_ADDR_P_OBUF(7),
      O => MEMORY_BANK2_ADDR_P(7)
    );

  obuf_49 : OBUF
    port map (
      I => MEMORY_BANK2_ADDR_P_OBUF(8),
      O => MEMORY_BANK2_ADDR_P(8)
    );

  obuf_50 : OBUF
    port map (
      I => MEMORY_BANK2_ADDR_P_OBUF(9),
      O => MEMORY_BANK2_ADDR_P(9)
    );

  obuf_51 : OBUF
    port map (
      I => MEMORY_BANK2_ADDR_P_OBUF(10),
      O => MEMORY_BANK2_ADDR_P(10)
    );

  obuf_52 : OBUF
    port map (
      I => MEMORY_BANK2_ADDR_P_OBUF(11),
      O => MEMORY_BANK2_ADDR_P(11)
    );

  obuf_53 : OBUF
    port map (
      I => MEMORY_BANK2_ADDR_P_OBUF(12),
      O => MEMORY_BANK2_ADDR_P(12)
    );

  obuf_54 : OBUF
    port map (
      I => MEMORY_BANK2_ADDR_P_OBUF(13),
      O => MEMORY_BANK2_ADDR_P(13)
    );

  obuf_55 : OBUF
    port map (
      I => MEMORY_BANK2_ADDR_P_OBUF(14),
      O => MEMORY_BANK2_ADDR_P(14)
    );

  obuf_56 : OBUF
    port map (
      I => MEMORY_BANK2_ADDR_P_OBUF(15),
      O => MEMORY_BANK2_ADDR_P(15)
    );

  obuf_57 : OBUF
    port map (
      I => MEMORY_BANK2_ADDR_P_OBUF(16),
      O => MEMORY_BANK2_ADDR_P(16)
    );

  obuf_58 : OBUF
    port map (
      I => MEMORY_BANK2_ADDR_P_OBUF(17),
      O => MEMORY_BANK2_ADDR_P(17)
    );

  obuf_59 : OBUF
    port map (
      I => MEMORY_BANK2_ADDR_P_OBUF(18),
      O => MEMORY_BANK2_ADDR_P(18)
    );

  obuf_60 : OBUF
    port map (
      I => MDC_P_OBUF,
      O => MDC_P
    );

  obuf_61 : OBUF
    port map (
      I => MDIO_P_OBUF,
      O => MDIO_P
    );

  obuf_62 : OBUF
    port map (
      I => STARTUP_P_OBUF,
      O => STARTUP_P
    );

  obuf_63 : OBUF
    port map (
      I => PAUSE_P_OBUF,
      O => PAUSE_P
    );

  obuf_64 : OBUF
    port map (
      I => ENET_SLEW_P_OBUF(0),
      O => ENET_SLEW_P(0)
    );

  obuf_65 : OBUF
    port map (
      I => ENET_SLEW_P_OBUF(1),
      O => ENET_SLEW_P(1)
    );

  ibuf_66 : IBUF
    port map (
      I => PAL_NTSC_N,
      O => PAL_NTSC_N_IBUF
    );

  ibuf_67 : IBUF
    port map (
      I => S_VIDEO_N,
      O => S_VIDEO_N_IBUF
    );

  ibuf_68 : IBUF
    port map (
      I => USER_INPUT1_P,
      O => USER_INPUT1_P_IBUF
    );

  ibuf_69 : IBUF
    port map (
      I => YCRCB(0),
      O => YCRCB_IBUF(0)
    );

  ibuf_70 : IBUF
    port map (
      I => YCRCB(1),
      O => YCRCB_IBUF(1)
    );

  ibuf_71 : IBUF
    port map (
      I => YCRCB(2),
      O => YCRCB_IBUF(2)
    );

  ibuf_72 : IBUF
    port map (
      I => YCRCB(3),
      O => YCRCB_IBUF(3)
    );

  ibuf_73 : IBUF
    port map (
      I => YCRCB(4),
      O => YCRCB_IBUF(4)
    );

  ibuf_74 : IBUF
    port map (
      I => YCRCB(5),
      O => YCRCB_IBUF(5)
    );

  ibuf_75 : IBUF
    port map (
      I => YCRCB(6),
      O => YCRCB_IBUF(6)
    );

  ibuf_76 : IBUF
    port map (
      I => YCRCB(7),
      O => YCRCB_IBUF(7)
    );

  ibuf_77 : IBUF
    port map (
      I => YCRCB(8),
      O => YCRCB_IBUF(8)
    );

  ibuf_78 : IBUF
    port map (
      I => YCRCB(9),
      O => YCRCB_IBUF(9)
    );

  obuf_79 : OBUF
    port map (
      I => YCRCB_P_OBUF(0),
      O => YCRCB_P(0)
    );

  obuf_80 : OBUF
    port map (
      I => YCRCB_P_OBUF(1),
      O => YCRCB_P(1)
    );

  obuf_81 : OBUF
    port map (
      I => YCRCB_P_OBUF(2),
      O => YCRCB_P(2)
    );

  obuf_82 : OBUF
    port map (
      I => YCRCB_P_OBUF(3),
      O => YCRCB_P(3)
    );

  obuf_83 : OBUF
    port map (
      I => YCRCB_P_OBUF(4),
      O => YCRCB_P(4)
    );

  obuf_84 : OBUF
    port map (
      I => YCRCB_P_OBUF(5),
      O => YCRCB_P(5)
    );

  obuf_85 : OBUF
    port map (
      I => YCRCB_P_OBUF(6),
      O => YCRCB_P(6)
    );

  obuf_86 : OBUF
    port map (
      I => YCRCB_P_OBUF(7),
      O => YCRCB_P(7)
    );

  obuf_87 : OBUF
    port map (
      I => YCRCB_P_OBUF(8),
      O => YCRCB_P(8)
    );

  obuf_88 : OBUF
    port map (
      I => YCRCB_P_OBUF(9),
      O => YCRCB_P(9)
    );

  ibuf_89 : IBUF
    port map (
      I => PB_DATA_P,
      O => PB_DATA_P_IBUF
    );

  ibuf_90 : IBUF
    port map (
      I => PB_CLOCK_P,
      O => PB_CLOCK_P_IBUF
    );

  obuf_91 : OBUF
    port map (
      I => RS232_TX_DATA_P_OBUF,
      O => RS232_TX_DATA_P
    );

  ibuf_92 : IBUF
    port map (
      I => RS232_RX_DATA_P,
      O => RS232_RX_DATA_P_IBUF
    );

  obuf_93 : OBUF
    port map (
      I => net_gnd0,
      O => MEM_CLK_FBOUT_P
    );

  obuf_94 : OBUF
    port map (
      I => STARTUP_P_OBUF,
      O => TV_OUT_BLANK_N
    );

  obuf_95 : OBUF
    port map (
      I => PAL_NTSC_N_IBUF,
      O => TV_OUT_PAL_NTSC_N
    );

end architecture STRUCTURE;
