-------------------------------------------------------------------------------
-- zbt_cntlr_wrapper.vhd
-------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

library common_v1_00_a;
use common_v1_00_a.all;

library opb_zbt_controller_v1_00_a;
use opb_zbt_controller_v1_00_a.all;

entity zbt_cntlr_wrapper is
  port (
    OPB_Clk : in std_logic;
    OPB_Rst : in std_logic;
    OPB_ABus : in std_logic_vector(0 to 31);
    OPB_BE : in std_logic_vector(0 to 3);
    OPB_RNW : in std_logic;
    OPB_select : in std_logic;
    OPB_seqAddr : in std_logic;
    OPB_DBus : in std_logic_vector(0 to 31);
    ZBT_DBus : out std_logic_vector(0 to 31);
    ZBT_errAck : out std_logic;
    ZBT_retry : out std_logic;
    ZBT_toutSup : out std_logic;
    ZBT_xferAck : out std_logic;
    ZBT_Clk_FB : in std_logic;
    ZBT_Clk_FBOut : out std_logic;
    ZBT_Clk : out std_logic;
    ZBT_OE_N : out std_logic;
    ZBT_ADV_LD_N : out std_logic;
    ZBT_LBO_N : out std_logic;
    ZBT_CE1_N : out std_logic;
    ZBT_CE2_N : out std_logic;
    ZBT_CE2 : out std_logic;
    ZBT_RW_N : out std_logic;
    ZBT_CKE_N : out std_logic;
    ZBT_A : out std_logic_vector(0 to 18);
    ZBT_BW_N : out std_logic_vector(1 to 4);
    ZBT_IO_I : in std_logic_vector(0 to 31);
    ZBT_IO_O : out std_logic_vector(0 to 31);
    ZBT_IO_T : out std_logic;
    ZBT_IOP_I : in std_logic_vector(1 to 4);
    ZBT_IOP_O : out std_logic_vector(1 to 4);
    ZBT_IOP_T : out std_logic
  );
end zbt_cntlr_wrapper;

architecture STRUCTURE of zbt_cntlr_wrapper is

  component opb_zbt_controller is
    generic (
      C_BASEADDR : std_logic_vector(0 to 31);
      C_HIGHADDR : std_logic_vector(0 to 31);
      C_ZBT_ADDR_SIZE : integer;
      C_EXTERNAL_DLL : integer
    );
    port (
      OPB_Clk : in std_logic;
      OPB_Rst : in std_logic;
      OPB_ABus : in std_logic_vector(0 to 31);
      OPB_BE : in std_logic_vector(0 to 3);
      OPB_RNW : in std_logic;
      OPB_select : in std_logic;
      OPB_seqAddr : in std_logic;
      OPB_DBus : in std_logic_vector(0 to 31);
      ZBT_DBus : out std_logic_vector(0 to 31);
      ZBT_errAck : out std_logic;
      ZBT_retry : out std_logic;
      ZBT_toutSup : out std_logic;
      ZBT_xferAck : out std_logic;
      ZBT_Clk_FB : in std_logic;
      ZBT_Clk_FBOut : out std_logic;
      ZBT_Clk : out std_logic;
      ZBT_OE_N : out std_logic;
      ZBT_ADV_LD_N : out std_logic;
      ZBT_LBO_N : out std_logic;
      ZBT_CE1_N : out std_logic;
      ZBT_CE2_N : out std_logic;
      ZBT_CE2 : out std_logic;
      ZBT_RW_N : out std_logic;
      ZBT_CKE_N : out std_logic;
      ZBT_A : out std_logic_vector(0 to C_ZBT_ADDR_SIZE-1);
      ZBT_BW_N : out std_logic_vector(1 to 4);
      ZBT_IO_I : in std_logic_vector(0 to 31);
      ZBT_IO_O : out std_logic_vector(0 to 31);
      ZBT_IO_T : out std_logic;
      ZBT_IOP_I : in std_logic_vector(1 to 4);
      ZBT_IOP_O : out std_logic_vector(1 to 4);
      ZBT_IOP_T : out std_logic
    );
  end component;

begin

  zbt_cntlr : opb_zbt_controller
    generic map (
      C_BASEADDR => X"00800000",
      C_HIGHADDR => X"0087FFFF",
      C_ZBT_ADDR_SIZE => 19,
      C_EXTERNAL_DLL => 1
    )
    port map (
      OPB_Clk => OPB_Clk,
      OPB_Rst => OPB_Rst,
      OPB_ABus => OPB_ABus,
      OPB_BE => OPB_BE,
      OPB_RNW => OPB_RNW,
      OPB_select => OPB_select,
      OPB_seqAddr => OPB_seqAddr,
      OPB_DBus => OPB_DBus,
      ZBT_DBus => ZBT_DBus,
      ZBT_errAck => ZBT_errAck,
      ZBT_retry => ZBT_retry,
      ZBT_toutSup => ZBT_toutSup,
      ZBT_xferAck => ZBT_xferAck,
      ZBT_Clk_FB => ZBT_Clk_FB,
      ZBT_Clk_FBOut => ZBT_Clk_FBOut,
      ZBT_Clk => ZBT_Clk,
      ZBT_OE_N => ZBT_OE_N,
      ZBT_ADV_LD_N => ZBT_ADV_LD_N,
      ZBT_LBO_N => ZBT_LBO_N,
      ZBT_CE1_N => ZBT_CE1_N,
      ZBT_CE2_N => ZBT_CE2_N,
      ZBT_CE2 => ZBT_CE2,
      ZBT_RW_N => ZBT_RW_N,
      ZBT_CKE_N => ZBT_CKE_N,
      ZBT_A => ZBT_A,
      ZBT_BW_N => ZBT_BW_N,
      ZBT_IO_I => ZBT_IO_I,
      ZBT_IO_O => ZBT_IO_O,
      ZBT_IO_T => ZBT_IO_T,
      ZBT_IOP_I => ZBT_IOP_I,
      ZBT_IOP_O => ZBT_IOP_O,
      ZBT_IOP_T => ZBT_IOP_T
    );

end architecture STRUCTURE;
