LIBRARY unisim;
USE unisim.vcomponents.ALL;

--------------------------------------------------------------------------------
-- lmbbram1_elaborate.vhd
--------------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.STD_LOGIC_1164.ALL;

-- synthesis translate_off
LIBRARY UNISIM;
USE UNISIM.VCOMPONENTS.ALL;
-- synthesis translate_on

ENTITY lmbbram1_elaborate IS
GENERIC (
	C_MEMSIZE : INTEGER := 32768;
	C_PORT_DWIDTH : INTEGER := 32;
	C_PORT_AWIDTH : INTEGER := 32;
	C_NUM_WE : INTEGER := 4;
	C_FAMILY : STRING := "virtex2");
PORT (
	-- instance GLOBAL
	BRAM_Addr_B : IN STD_LOGIC_VECTOR(0 TO 31);
	BRAM_Dout_A : IN STD_LOGIC_VECTOR(0 TO 31);
	BRAM_EN_A : IN STD_LOGIC;
	BRAM_Dout_B : IN STD_LOGIC_VECTOR(0 TO 31);
	BRAM_EN_B : IN STD_LOGIC;
	BRAM_Din_A : OUT STD_LOGIC_VECTOR(0 TO 31);
	BRAM_Din_B : OUT STD_LOGIC_VECTOR(0 TO 31);
	BRAM_Clk_A : IN STD_LOGIC;
	BRAM_WEN_A : IN STD_LOGIC_VECTOR(0 TO 3);
	BRAM_WEN_B : IN STD_LOGIC_VECTOR(0 TO 3);
	BRAM_Clk_B : IN STD_LOGIC;
	BRAM_Rst_A : IN STD_LOGIC;
	BRAM_Rst_B : IN STD_LOGIC;
	BRAM_Addr_A : IN STD_LOGIC_VECTOR(0 TO 31));
END lmbbram1_elaborate;

ARCHITECTURE IMP OF lmbbram1_elaborate IS

--------------------------------------------------------------------------------
COMPONENT RAMB16_S2_S2 IS
PORT (
	CLKB : IN STD_LOGIC;
	ADDRA : IN STD_LOGIC_VECTOR(12 DOWNTO 0);
	ADDRB : IN STD_LOGIC_VECTOR(12 DOWNTO 0);
	DOA : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
	DOB : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
	ENA : IN STD_LOGIC;
	SSRA : IN STD_LOGIC;
	ENB : IN STD_LOGIC;
	SSRB : IN STD_LOGIC;
	DIA : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
	DIB : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
	WEA : IN STD_LOGIC;
	WEB : IN STD_LOGIC;
	CLKA : IN STD_LOGIC);
END COMPONENT;

--------------------------------------------------------------------------------
-- internal signals
--------------------------------------------------------------------------------

	SIGNAL dina : STD_LOGIC_VECTOR(31 DOWNTO 0);

	SIGNAL dinb : STD_LOGIC_VECTOR(31 DOWNTO 0);

	SIGNAL douta : STD_LOGIC_VECTOR(31 DOWNTO 0);

	SIGNAL doutb : STD_LOGIC_VECTOR(31 DOWNTO 0);

	SIGNAL net_gnd0 : STD_LOGIC;

BEGIN

--------------------------------------------------------------------------------
-- Power assignments
net_gnd0 <= '0';
--------------------------------------------------------------------------------
-- Constant assignments
--------------------------------------------------------------------------------
-- Top-level port assignments
dina <= BRAM_Dout_A;
dinb <= BRAM_Dout_B;
BRAM_Din_A <= douta;
BRAM_Din_B <= doutb;
--------------------------------------------------------------------------------
-- Lower-level assignments

--------------------------------------------------------------------------------
ramb16_s2_s2_0 : RAMB16_S2_S2
PORT MAP (
	CLKB => BRAM_Clk_B,
	ADDRA => BRAM_Addr_A(17 TO 29),
	ADDRB => BRAM_Addr_B(17 TO 29),
	DOA => douta(31 DOWNTO 30),
	DOB => doutb(31 DOWNTO 30),
	ENA => BRAM_EN_A,
	SSRA => net_gnd0,
	ENB => BRAM_EN_B,
	SSRB => net_gnd0,
	DIA => dina(31 DOWNTO 30),
	DIB => dinb(31 DOWNTO 30),
	WEA => BRAM_WEN_A(0),
	WEB => BRAM_WEN_B(0),
	CLKA => BRAM_Clk_A);

--------------------------------------------------------------------------------
ramb16_s2_s2_1 : RAMB16_S2_S2
PORT MAP (
	CLKB => BRAM_Clk_B,
	ADDRA => BRAM_Addr_A(17 TO 29),
	ADDRB => BRAM_Addr_B(17 TO 29),
	DOA => douta(29 DOWNTO 28),
	DOB => doutb(29 DOWNTO 28),
	ENA => BRAM_EN_A,
	SSRA => net_gnd0,
	ENB => BRAM_EN_B,
	SSRB => net_gnd0,
	DIA => dina(29 DOWNTO 28),
	DIB => dinb(29 DOWNTO 28),
	WEA => BRAM_WEN_A(0),
	WEB => BRAM_WEN_B(0),
	CLKA => BRAM_Clk_A);

--------------------------------------------------------------------------------
ramb16_s2_s2_2 : RAMB16_S2_S2
PORT MAP (
	CLKB => BRAM_Clk_B,
	ADDRA => BRAM_Addr_A(17 TO 29),
	ADDRB => BRAM_Addr_B(17 TO 29),
	DOA => douta(27 DOWNTO 26),
	DOB => doutb(27 DOWNTO 26),
	ENA => BRAM_EN_A,
	SSRA => net_gnd0,
	ENB => BRAM_EN_B,
	SSRB => net_gnd0,
	DIA => dina(27 DOWNTO 26),
	DIB => dinb(27 DOWNTO 26),
	WEA => BRAM_WEN_A(0),
	WEB => BRAM_WEN_B(0),
	CLKA => BRAM_Clk_A);

--------------------------------------------------------------------------------
ramb16_s2_s2_3 : RAMB16_S2_S2
PORT MAP (
	CLKB => BRAM_Clk_B,
	ADDRA => BRAM_Addr_A(17 TO 29),
	ADDRB => BRAM_Addr_B(17 TO 29),
	DOA => douta(25 DOWNTO 24),
	DOB => doutb(25 DOWNTO 24),
	ENA => BRAM_EN_A,
	SSRA => net_gnd0,
	ENB => BRAM_EN_B,
	SSRB => net_gnd0,
	DIA => dina(25 DOWNTO 24),
	DIB => dinb(25 DOWNTO 24),
	WEA => BRAM_WEN_A(0),
	WEB => BRAM_WEN_B(0),
	CLKA => BRAM_Clk_A);

--------------------------------------------------------------------------------
ramb16_s2_s2_4 : RAMB16_S2_S2
PORT MAP (
	CLKB => BRAM_Clk_B,
	ADDRA => BRAM_Addr_A(17 TO 29),
	ADDRB => BRAM_Addr_B(17 TO 29),
	DOA => douta(23 DOWNTO 22),
	DOB => doutb(23 DOWNTO 22),
	ENA => BRAM_EN_A,
	SSRA => net_gnd0,
	ENB => BRAM_EN_B,
	SSRB => net_gnd0,
	DIA => dina(23 DOWNTO 22),
	DIB => dinb(23 DOWNTO 22),
	WEA => BRAM_WEN_A(1),
	WEB => BRAM_WEN_B(1),
	CLKA => BRAM_Clk_A);

--------------------------------------------------------------------------------
ramb16_s2_s2_5 : RAMB16_S2_S2
PORT MAP (
	CLKB => BRAM_Clk_B,
	ADDRA => BRAM_Addr_A(17 TO 29),
	ADDRB => BRAM_Addr_B(17 TO 29),
	DOA => douta(21 DOWNTO 20),
	DOB => doutb(21 DOWNTO 20),
	ENA => BRAM_EN_A,
	SSRA => net_gnd0,
	ENB => BRAM_EN_B,
	SSRB => net_gnd0,
	DIA => dina(21 DOWNTO 20),
	DIB => dinb(21 DOWNTO 20),
	WEA => BRAM_WEN_A(1),
	WEB => BRAM_WEN_B(1),
	CLKA => BRAM_Clk_A);

--------------------------------------------------------------------------------
ramb16_s2_s2_6 : RAMB16_S2_S2
PORT MAP (
	CLKB => BRAM_Clk_B,
	ADDRA => BRAM_Addr_A(17 TO 29),
	ADDRB => BRAM_Addr_B(17 TO 29),
	DOA => douta(19 DOWNTO 18),
	DOB => doutb(19 DOWNTO 18),
	ENA => BRAM_EN_A,
	SSRA => net_gnd0,
	ENB => BRAM_EN_B,
	SSRB => net_gnd0,
	DIA => dina(19 DOWNTO 18),
	DIB => dinb(19 DOWNTO 18),
	WEA => BRAM_WEN_A(1),
	WEB => BRAM_WEN_B(1),
	CLKA => BRAM_Clk_A);

--------------------------------------------------------------------------------
ramb16_s2_s2_7 : RAMB16_S2_S2
PORT MAP (
	CLKB => BRAM_Clk_B,
	ADDRA => BRAM_Addr_A(17 TO 29),
	ADDRB => BRAM_Addr_B(17 TO 29),
	DOA => douta(17 DOWNTO 16),
	DOB => doutb(17 DOWNTO 16),
	ENA => BRAM_EN_A,
	SSRA => net_gnd0,
	ENB => BRAM_EN_B,
	SSRB => net_gnd0,
	DIA => dina(17 DOWNTO 16),
	DIB => dinb(17 DOWNTO 16),
	WEA => BRAM_WEN_A(1),
	WEB => BRAM_WEN_B(1),
	CLKA => BRAM_Clk_A);

--------------------------------------------------------------------------------
ramb16_s2_s2_8 : RAMB16_S2_S2
PORT MAP (
	CLKB => BRAM_Clk_B,
	ADDRA => BRAM_Addr_A(17 TO 29),
	ADDRB => BRAM_Addr_B(17 TO 29),
	DOA => douta(15 DOWNTO 14),
	DOB => doutb(15 DOWNTO 14),
	ENA => BRAM_EN_A,
	SSRA => net_gnd0,
	ENB => BRAM_EN_B,
	SSRB => net_gnd0,
	DIA => dina(15 DOWNTO 14),
	DIB => dinb(15 DOWNTO 14),
	WEA => BRAM_WEN_A(2),
	WEB => BRAM_WEN_B(2),
	CLKA => BRAM_Clk_A);

--------------------------------------------------------------------------------
ramb16_s2_s2_9 : RAMB16_S2_S2
PORT MAP (
	CLKB => BRAM_Clk_B,
	ADDRA => BRAM_Addr_A(17 TO 29),
	ADDRB => BRAM_Addr_B(17 TO 29),
	DOA => douta(13 DOWNTO 12),
	DOB => doutb(13 DOWNTO 12),
	ENA => BRAM_EN_A,
	SSRA => net_gnd0,
	ENB => BRAM_EN_B,
	SSRB => net_gnd0,
	DIA => dina(13 DOWNTO 12),
	DIB => dinb(13 DOWNTO 12),
	WEA => BRAM_WEN_A(2),
	WEB => BRAM_WEN_B(2),
	CLKA => BRAM_Clk_A);

--------------------------------------------------------------------------------
ramb16_s2_s2_10 : RAMB16_S2_S2
PORT MAP (
	CLKB => BRAM_Clk_B,
	ADDRA => BRAM_Addr_A(17 TO 29),
	ADDRB => BRAM_Addr_B(17 TO 29),
	DOA => douta(11 DOWNTO 10),
	DOB => doutb(11 DOWNTO 10),
	ENA => BRAM_EN_A,
	SSRA => net_gnd0,
	ENB => BRAM_EN_B,
	SSRB => net_gnd0,
	DIA => dina(11 DOWNTO 10),
	DIB => dinb(11 DOWNTO 10),
	WEA => BRAM_WEN_A(2),
	WEB => BRAM_WEN_B(2),
	CLKA => BRAM_Clk_A);

--------------------------------------------------------------------------------
ramb16_s2_s2_11 : RAMB16_S2_S2
PORT MAP (
	CLKB => BRAM_Clk_B,
	ADDRA => BRAM_Addr_A(17 TO 29),
	ADDRB => BRAM_Addr_B(17 TO 29),
	DOA => douta(9 DOWNTO 8),
	DOB => doutb(9 DOWNTO 8),
	ENA => BRAM_EN_A,
	SSRA => net_gnd0,
	ENB => BRAM_EN_B,
	SSRB => net_gnd0,
	DIA => dina(9 DOWNTO 8),
	DIB => dinb(9 DOWNTO 8),
	WEA => BRAM_WEN_A(2),
	WEB => BRAM_WEN_B(2),
	CLKA => BRAM_Clk_A);

--------------------------------------------------------------------------------
ramb16_s2_s2_12 : RAMB16_S2_S2
PORT MAP (
	CLKB => BRAM_Clk_B,
	ADDRA => BRAM_Addr_A(17 TO 29),
	ADDRB => BRAM_Addr_B(17 TO 29),
	DOA => douta(7 DOWNTO 6),
	DOB => doutb(7 DOWNTO 6),
	ENA => BRAM_EN_A,
	SSRA => net_gnd0,
	ENB => BRAM_EN_B,
	SSRB => net_gnd0,
	DIA => dina(7 DOWNTO 6),
	DIB => dinb(7 DOWNTO 6),
	WEA => BRAM_WEN_A(3),
	WEB => BRAM_WEN_B(3),
	CLKA => BRAM_Clk_A);

--------------------------------------------------------------------------------
ramb16_s2_s2_13 : RAMB16_S2_S2
PORT MAP (
	CLKB => BRAM_Clk_B,
	ADDRA => BRAM_Addr_A(17 TO 29),
	ADDRB => BRAM_Addr_B(17 TO 29),
	DOA => douta(5 DOWNTO 4),
	DOB => doutb(5 DOWNTO 4),
	ENA => BRAM_EN_A,
	SSRA => net_gnd0,
	ENB => BRAM_EN_B,
	SSRB => net_gnd0,
	DIA => dina(5 DOWNTO 4),
	DIB => dinb(5 DOWNTO 4),
	WEA => BRAM_WEN_A(3),
	WEB => BRAM_WEN_B(3),
	CLKA => BRAM_Clk_A);

--------------------------------------------------------------------------------
ramb16_s2_s2_14 : RAMB16_S2_S2
PORT MAP (
	CLKB => BRAM_Clk_B,
	ADDRA => BRAM_Addr_A(17 TO 29),
	ADDRB => BRAM_Addr_B(17 TO 29),
	DOA => douta(3 DOWNTO 2),
	DOB => doutb(3 DOWNTO 2),
	ENA => BRAM_EN_A,
	SSRA => net_gnd0,
	ENB => BRAM_EN_B,
	SSRB => net_gnd0,
	DIA => dina(3 DOWNTO 2),
	DIB => dinb(3 DOWNTO 2),
	WEA => BRAM_WEN_A(3),
	WEB => BRAM_WEN_B(3),
	CLKA => BRAM_Clk_A);

--------------------------------------------------------------------------------
ramb16_s2_s2_15 : RAMB16_S2_S2
PORT MAP (
	CLKB => BRAM_Clk_B,
	ADDRA => BRAM_Addr_A(17 TO 29),
	ADDRB => BRAM_Addr_B(17 TO 29),
	DOA => douta(1 DOWNTO 0),
	DOB => doutb(1 DOWNTO 0),
	ENA => BRAM_EN_A,
	SSRA => net_gnd0,
	ENB => BRAM_EN_B,
	SSRB => net_gnd0,
	DIA => dina(1 DOWNTO 0),
	DIB => dinb(1 DOWNTO 0),
	WEA => BRAM_WEN_A(3),
	WEB => BRAM_WEN_B(3),
	CLKA => BRAM_Clk_A);

END ARCHITECTURE IMP;
