/*
-------------------------------------------------------------------------------
   Title      : resync_buffer
   Project    : MicroBlaze Demo Board
-------------------------------------------------------------------------------
   File       : comp_vid_test_top.v
   Author     : mark.paluszkiewicz@Xilinx.com>
   Company    : Xilinx, Inc.
   Created    : 
   Last Update: 
   Copyright  : (c) Xilinx Inc, 2001
-------------------------------------------------------------------------------
   Uses       :used to resync the video in to the vidoe out clock 
-------------------------------------------------------------------------------
   Used by    : Any user logic in the MicroBlaze demo board FPGA
-------------------------------------------------------------------------------
   Description: Top level design for MicrobBlaze Processor and IIC programming of the Video chips
                  to test the Microblaze board.

        This module is used to
        Conventions:
                All port signals are UPPER CASE.
                Active HIGH PORT signals have a P suffex
                Active LOW PORT signals have a N suffex.
                All internal signals are LOWER CASE and are active HIGH.

-------------------------------------------------------------------------------
   Revisions  :
   Date        Version  Author            Description
   2002/05/21  1.0      Paluszkiewicz   Initial Release

-------------------------------------------------------------------------------
*/
module vid_resync_buf(
vid_clk_27mhz_out,
clk_27mhz,
dcm_reset,
YCrCb,
YCrCb_P,
);

input vid_clk_27mhz_out;
input clk_27mhz;
input dcm_reset;
input [9:0]  YCrCb;
output [9:0] YCrCb_P;



reg [9:0] reg_ycrcb_in;
reg [9:0] reg_ycrcb_out;
wire [9:0] rsync_ycrcb_out;

reg [10:0] vid_in_adr_cnt;
reg [10:0] vid_out_adr_cnt;
wire[2:0] 		open;
wire            low;
wire            high;
wire [7:0]		low8b;
wire [2:0]		low3b;

assign low  = 1'b0;
assign low8b  = 8'b0;
assign low3b = 3'b0;
assign high = 1'b1;

always @(posedge vid_clk_27mhz_out or posedge dcm_reset)
begin
   if (dcm_reset)
      reg_ycrcb_in = 9'b0;
   else
      reg_ycrcb_in = YCrCb;
end

always @(posedge vid_clk_27mhz_out or posedge dcm_reset)
begin
   if (dcm_reset)
      vid_in_adr_cnt = 10'b0;
   else
      vid_in_adr_cnt = vid_in_adr_cnt + 1;
end

always @(posedge clk_27mhz or posedge dcm_reset)
begin
   if (dcm_reset)
      reg_ycrcb_out = 9'b0;
   else
      reg_ycrcb_out = rsync_ycrcb_out;
end

always @(posedge clk_27mhz or posedge dcm_reset)
begin
   if (dcm_reset)
      vid_out_adr_cnt = "01111111111";
   else
      vid_out_adr_cnt = vid_out_adr_cnt + 1;
end

assign YCrCb_P = reg_ycrcb_out;

RAMB16_S9_S9 Upper_Ram(
.DOA(),
.DOPA(), 
.DOB(rsync_ycrcb_out[9:5]), 
.DOPB(), 
.ADDRA(vid_in_adr_cnt), 
.CLKA(vid_clk_27mhz_out), 
.DIA(reg_ycrcb_in[9:5]), 
.DIPA(low), 
.ENA(high), 
.SSRA(low), 
.WEA(high), 
.ADDRB(vid_out_adr_cnt), 
.CLKB(clk_27mhz), 
.DIB(low8b), 
.DIPB(low),
.ENB(high), 
.SSRB(low), 
.WEB(low)
);

RAMB16_S9_S9 Lower_Ram(
.DOA(),
.DOPA(), 
.DOB(rsync_ycrcb_out[4:0]), 
.DOPB(), 
.ADDRA(vid_in_adr_cnt), 
.CLKA(vid_clk_27mhz_out), 
.DIA(reg_ycrcb_in[4:0]), 
.DIPA(low), 
.ENA(high), 
.SSRA(low), 
.WEA(high), 
.ADDRB(vid_out_adr_cnt), 
.CLKB(clk_27mhz), 
.DIB(low8b), 
.DIPB(low),
.ENB(high), 
.SSRB(low), 
.WEB(low)
);

endmodule // end of resync buffer


/*
FUNCTION	: 16x9x9 Block RAM with synchronous write capability
*/
/*
module RAMB16_S9_S9 (DOA, DOPA, DOB, DOPB, ADDRA, CLKA, DIA, DIPA, ENA, SSRA, WEA, ADDRB, CLKB, DIB, DIPB, ENB, SSRB, WEB);

//synthesis translate_off

    defparam RAMB_EXAMPLE.INIT_A = 9'h0;
    defparam RAMB_EXAMPLE.INIT_B = 9'h0;
    defparam RAMB_EXAMPLE.SRVAL_A = 9'h0;
    defparam RAMB_EXAMPLE.SRVAL_B = 9'h0;
    defparam RAMB_EXAMPLE.WRITE_MODE_A = "WRITE_FIRST";
    defparam RAMB_EXAMPLE.WRITE_MODE_B = "WRITE_FIRST";
    defparam RAMB_EXAMPLE.INIT_00 = 256'h0000000000000000000000000000000000000000000000000000000000000000;
    defparam RAMB_EXAMPLE.INIT_01 = 256'h0000000000000000000000000000000000000000000000000000000000000000;
    defparam RAMB_EXAMPLE.INIT_02 = 256'h0000000000000000000000000000000000000000000000000000000000000000;
    defparam RAMB_EXAMPLE.INIT_03 = 256'h0000000000000000000000000000000000000000000000000000000000000000;
    defparam RAMB_EXAMPLE.INIT_04 = 256'h0000000000000000000000000000000000000000000000000000000000000000;
    defparam RAMB_EXAMPLE.INIT_05 = 256'h0000000000000000000000000000000000000000000000000000000000000000;
    defparam RAMB_EXAMPLE.INIT_06 = 256'h0000000000000000000000000000000000000000000000000000000000000000;
    defparam RAMB_EXAMPLE.INIT_07 = 256'h0000000000000000000000000000000000000000000000000000000000000000;
    defparam RAMB_EXAMPLE.INIT_08 = 256'h0000000000000000000000000000000000000000000000000000000000000000;
    defparam RAMB_EXAMPLE.INIT_09 = 256'h0000000000000000000000000000000000000000000000000000000000000000;
    defparam RAMB_EXAMPLE.INIT_0A = 256'h0000000000000000000000000000000000000000000000000000000000000000;
    defparam RAMB_EXAMPLE.INIT_0B = 256'h0000000000000000000000000000000000000000000000000000000000000000;
    defparam RAMB_EXAMPLE.INIT_0C = 256'h0000000000000000000000000000000000000000000000000000000000000000;
    defparam RAMB_EXAMPLE.INIT_0D = 256'h0000000000000000000000000000000000000000000000000000000000000000;
    defparam RAMB_EXAMPLE.INIT_0E = 256'h0000000000000000000000000000000000000000000000000000000000000000;
    defparam RAMB_EXAMPLE.INIT_0F = 256'h0000000000000000000000000000000000000000000000000000000000000000;
    defparam RAMB_EXAMPLE.INITP_00 = 256'h0000000000000000000000000000000000000000000000000000000000000000;
    defparam RAMB_EXAMPLE.INITP_01 = 256'h0000000000000000000000000000000000000000000000000000000000000000;
    defparam RAMB_EXAMPLE.INITP_02 = 256'h0000000000000000000000000000000000000000000000000000000000000000;
    defparam RAMB_EXAMPLE.INITP_03 = 256'h0000000000000000000000000000000000000000000000000000000000000000;
    defparam RAMB_EXAMPLE.INITP_04 = 256'h0000000000000000000000000000000000000000000000000000000000000000;
    defparam RAMB_EXAMPLE.INITP_05 = 256'h0000000000000000000000000000000000000000000000000000000000000000;
    defparam RAMB_EXAMPLE.INITP_06 = 256'h0000000000000000000000000000000000000000000000000000000000000000;
    defparam RAMB_EXAMPLE.INITP_07 = 256'h0000000000000000000000000000000000000000000000000000000000000000;

//synthesis translate_on

//synthesis attribute INIT_00 of RAMB_EXAMPLE is "0000000000000000000000000000000000000000000000000000000000000000" 
//synthesis attribute INIT_01 of RAMB_EXAMPLE is "0000000000000000000000000000000000000000000000000000000000000000" 

    output [7:0] DOA;
    output [0:0] DOPA;
    input [10:0] ADDRA;
    input [7:0] DIA;
    input [0:0] DIPA;
    input ENA, CLKA, WEA, SSRA;
    output [7:0] DOB;
    output [0:0] DOPB;
    input [10:0] ADDRB;
    input [7:0] DIB;
    input [0:0] DIPB;
    input ENB, CLKB, WEB, SSRB;
endmodule
*/
